/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Skopek, Jan and Leopold, Thomas (2020). Educational Reproduction in Germany: 
  A Prospective Study Based on Retrospective Data. In: Demography.
  
  00_retrospective_data.do 
  
  Prepare survey data from the NEPS and the SOEP. 
  
  Produces 00_retrospective_data.dta in temp folder. 
  
  ------------------------------------------------------------------------------
------------------------------------------------------------------------------*/

// path to NEPS data

/*----------------------------------------------------
 
 I) NEPS Data Preparation

 ----------------------------------------------------*/

// The method file of NEPS includes important methodological information
use "${data_neps}/SC6_Methods_D_5-1-0.dta", clear

// select wave 4 (2011/12)
keep if wave == 4
// last interview

keep ID_t wave inty tx80107 tx80101 tx80220 

isid ID_t

tempfile methods
save `methods'

// Basics file contains most recent information on whole sample (for some, that might be from wave 5)
use "${data_neps}/SC6_Basics_D_5-1-0.dta", clear

// age, date of birth, education, mother/father: education, born in Germany
keep ID_t tx29000 t700001 t70000m t70000y tx28103 tx28101 tx28102 tx29000 tx29505 t731301_g* tx29705 t731351_g* t731453_g8 t731453_g5

nepsmiss // nepsmiss codes NEPS specific missing values

rename t700001 sex
rename t731301_g1 mothISCED
rename t731301_g2 mothCAS
rename t731301_g3 mothCASy 
rename t731351_g1 fathISCED
rename t731351_g2 fathCAS
rename t731351_g3 fathCASy

recode tx29505 (2=0) (1=1), gen(mothGerm)
recode tx29705 (2=0) (1=1), gen(fathGerm)
   
gen double bdate = ym(t70000y, t70000m) 
format bdate %tm 
lab var bdate "birth date"
drop t70000y t70000m
rename tx28103 ISCED
rename tx28101 CAS
rename tx28102 CASy
rename t731453_g5 fathISEI88
rename t731453_g8 fathEGP
tempfile basics
save `basics'


// pTarget: data file contains data from the interviews
// Data on siblings and parents
// siblings, birth date of parents 
use "${data_neps}/SC6_pTarget_D_5-1-0.dta", clear 

keep ID_t wave t732101 t73125y t73120y t731101 t405000_g2  // "eigene Kinder -> ts33101, was asked from NEPS wave 3 onwards"
nepsmiss
rename t732101 sibl
rename t73125y fathbrth
rename t73120y mothbrth
rename t731101 famform15
rename t405000_g2 brthplce

// sibling questions were asked in 2009/10, 10/11 and 11/12
tabstat sibl, by(wave)
tabstat fathbrth, by(wave) // father's birth was not asked in 10/11 and 12/13
tabstat mothbrth, by(wave) // mother's birth was not asked in 10/11 and 12/13
tabstat famform15, by(wave) // family form at age 15 was not asked in 10/11 and 12/13
tabstat brthplce, by(wave) // place of birth was not asked in 10/11 and 12/13

// take most recent reported non-missing value
reshape wide sibl fathbrth mothbrth famform15 brthplce, i(ID_t) j(wave)
egen sibl = rowlast(sibl?)
egen fathbrth = rowlast(fathbrth?)
egen mothbrth = rowlast(mothbrth?)
egen famform15 = rowlast(famform15?)
egen brthplce = rowlast(brthplce?)

lab val brthplce de2365
lab var brthplce "born in"
lab val sibl deext13
lab var sibl "siblings"
lab val fathbrth deext10
lab var fathbrth "father date of birth"
lab val mothbrth deext9
lab var mothbrth "mother date of birth"
lab val famform15 de444  
lab var famform15 "family form at age 15"
drop sibl? fathbrth? mothbrth? famform15? brthplce?

// Sibling data is structurally missing for some respondents (around 7%)
// becuase it has been collected not earlier than NEPS wave 2
fre sibl // for some there is no sibling information (has been collected not earlier than NEPS wave 2)
recode famform15 (1 = 0 "nein") (2 3 4 5 6 = 1 "ja"), gen(notintact)
lab var notintact "not intact origin family (e.g. divorce)"

tempfile ptarget
save `ptarget' 

// The weights data set contains all cases and sampling information
use "${data_neps}/SC6_Weights_D_5-1-0.dta", clear
count // 17.140 cases

// restricts to wave 4 participants only
merge 1:1 ID_t using `basics', assert(matched) nogen
merge 1:1 ID_t using `ptarget', assert(matched) nogen
merge 1:1 ID_t using `methods', assert(master match) keep(match) nogen

count // 16,597 (participants in wave 4)

// dummy for respondent's educational level, abitur or more; will be child variable later
recode CAS (0/4=0) (5/8=1) (else=.), gen(cabi)

// Dummies for father's and mother's education
recode  fathCAS (0/4=0) (5/8=1), gen(vabi)
recode  mothCAS (0/4=0) (5/8=1), gen(mabi)

// Code respondent's date of birth
gen brth = year(dofm(bdate))
lab var brth "birth of respondent"

// East and West - define by place of birth of respondent (!)
recode brthplce ( 1 3 4 = 2 "West") (2 = 1 "East"), gen(part) 
// count born abroad and in former eastern German territories to West
// but if neither father nor mother was born in Germany we recode "part" to missing
replace part = . if mothGerm!=1 & fathGerm!=1

// born in Germany? 
recode brthplce (1 2 4 = 1) (3=0), gen(bornde)

// top-code sibling numbers at 10 siblings max
gen sibl_coded = min(sibl,10) if sibl < .
lab var sibl_coded "siblings (top-coded at 10)"
 
// Number of children of parents
// gen F = sibl_coded+1
// lab var F "Fertility of parents (top-coded)"

// female dummy
gen female = sex==2
lab var female "sex of respondent"

// age
gen age = inty - brth 


// Sample of panel entry
recode tx80107 (1 2 = 1 "NEPS 2009") (4 = 2 "NEPS 2011/12"), gen(entry)

// weight variable (wave 4 weight)
gen sw = w_t4_cal 

// replace 0-weights with missing
replace sw = . if sw==0

// drop very few cases with missing weight (n=4)
drop if sw== .

// 
isid ID_t
gen data = 0 
keep ID_t tx80101 tx80107 age sex bdate sibl bornde fathbrth mothbrth mothGerm brthplce fathGerm cabi vabi mabi brth part female sw data

tempfile NEPS
save `NEPS', replace


/*----------------------------------------------------
 
 II) SOEP data preparation

 ----------------------------------------------------*/
 
global soep 

set more off

// PARENT DATA – parental education, birth date of parents, number of siblings
use "${data_soep_wide}/bioparen.dta", clear

keep persnr bioyear vgebj visei vegp vnat mnat mgebj vsbil msbil vbbil mbbil alter malter valter morigin vorigin geschw nums numb

tab vbbil vsbil

// casmin coding
gen vabi = 1 if inlist(vsbil,3,4)
replace vabi = 0 if !inlist(vsbil,3,4) & vsbil>0
replace vabi = 1 if inlist(vbbil,30,31,32) 
// replace vabi = 1 if inlist(vbbil, 26,27) & mi(vabi)	// in most non-missing cases that's not abitur!
// replace vabi = 0 if !inlist(26,27,30,31,32) & vbbil > 0 & mi(vabi)
replace vabi = 0 if !inlist(30,31,32) & vbbil > 0 & mi(vabi)

gen mabi = 1 if inlist(msbil,3,4)
replace mabi = 0 if !inlist(msbil,3,4) & msbil>0
replace mabi = 1 if inlist(mbbil,30,31,32) 
// replace mabi = 1 if inlist(mbbil, 26,27) & mi(mabi)	// in most non-missing cases that's not abitur!
// replace mabi = 0 if !inlist(26,27,30,31,32) & mbbil > 0 & mi(mabi)
replace mabi = 0 if !inlist(30,31,32) & mbbil > 0 & mi(mabi)

fre vabi if vsbil<=0 & vbbil<=0

// gen isced for father and mother (see coding scheme in pgen documentation page 52)

// classify training first
// ISCED 6: (the following overrides schooling)
//	[30] FHS,Ingeniuerschule
//	[31] Ausl. Hochschule
//	[32] Hochsch.,Universit.
gen visced = 6 if inlist(vbbil, 30, 31,32)
gen misced = 6 if inlist(mbbil, 30, 31,32)
// ISCED 5: 
//	[26] Schule Gesundheitsw.
//  [27] FS,Techn.-o.Meisters 
replace visced = 5 if inlist(vbbil, 26, 27)
replace misced = 5 if inlist(mbbil, 26, 27)

//   combined with schooling
//  [28] Beamtenausbildung + Abitur/F-Abitur or weiterführende schule
replace visced = 5 if inlist(vbbil, 28) & inlist(vsbil,3,4) // only abitur & fach-abitur
replace misced = 5 if inlist(mbbil, 28) & inlist(msbil,3,4) // only abitur & fach-abitur

// ISCED 4: in combination with schooling Abitur/Fachabitur only
//	[20] beruflicheAusbildung
//  [22] Laeng.Ausb.i.ausl.B.
//  [23] Berufsbild.ausl.Sch.
//  [24] Gewerbl.o.Lw.Lehre
//  [25] Kaufm.L.,Bfs,Handels
//  [40] Sonstige Ausbildung
replace visced = 4 if inlist(vbbil, 20,22,23,24,25,40) & inlist(vsbil,3,4) // only abitur & fach-abitur
replace misced = 4 if inlist(mbbil, 20,22,23,24,25,40) & inlist(msbil,3,4) // only abitur & fach-abitur

// ISCED 3: either abitur/fachabitur or training
replace visced = 3 if mi(visced) & ( inlist(vbbil, 20,22,23,24,25,40) | inlist(vsbil,3,4) )
replace misced = 3 if mi(misced) & ( inlist(mbbil, 20,22,23,24,25,40) | inlist(msbil,3,4) )

// ISCED 2: schooling only HS & RS
// [1] Hauptschule
// [2] Realschule
replace visced = 2 if mi(visced) & inlist(vsbil,1,2) 
replace misced = 2 if mi(misced) & inlist(msbil,1,2) 

// ISCED 1: basic schooling only or no schooling
// [5] sonstiger Abschluss
// [6] Kein Abschluss
// [7] Keine Schule besucht
replace visced = 1 if mi(visced) & inlist(vsbil,5,6,7) 
replace misced = 1 if mi(misced) & inlist(msbil,5,6,7) 

// Residuals: 
// [28] Beamtenausbildung as training, but no schooling data -> isced 3
replace visced = 3 if mi(visced) & inlist(vbbil,28)
replace misced = 3 if mi(misced) & inlist(mbbil,28)

// [10] Keine abg.Ausbildung, and no schooling data --> isced 2 
replace visced = 2 if mi(visced) & inlist(vbbil,10)
replace misced = 2 if mi(misced) & inlist(mbbil,10)

fre vsbil vbbil if visced == .
fre msbil mbbil if misced == .

lab def isced 1 "isced 0/1" 2 "isced 2" 3 "isced 3" 4 "isced 4" 5 "isced 5" 6 "isced 6" 
lab val visced isced
lab val misced isced
lab var visced "father ISCED-97"
lab var misced "mother ISCED-97"

rename persnr pid
keep pid misced visced visei vegp mabi vabi vgebj mgebj vgebj mgebj vnat mnat morigin vorigin geschw nums numb bioyear alter

tempfile parents
save `parents'


// person data (soep long)
// 

use "${data_soep_long}/ppfadl.dta", clear

// keep only those with valid birth date
keep if gebjahr > 0

// keep only those responding
keep if erstbefr > 0

// keep those born in Germany
// keep if germborn==1

// drop sub-samples
// keep only the following subsamples (which are probability samples)
/*
           1 [1] A 1984 Ausgangs-Sample (West)
           3 [3] C 1990 Ausgangs-Sample (Ost)
           5 [5] E 1998 Aufstockung
           6 [6] F 2000 Aufstockung
           8 [8] H 2006 Aufstockung
          10 [10] J 2011 Aufstockung
          11 [11] K 2012 Aufstockung
*/
// restrict to cross-section 2012
keep if syear == 2012
// keep only probability samples
inspect phrf
count if phrf == 0
drop if phrf == 0

// keep if inlist(psample, 1,3,5,6,8,10,11)


count

merge 1:1 pid syear using "${data_soep_long}/pgen", keepusing(pgcasmin) keep(master matched) 
merge n:1 pid using `parents', keep(master matched) gen(_parents)

// EDUCATION
recode pgcasmin (0/5=0) (6/9=1) (else=.), gen(cabi)

// recode mother's father's year of birth
recode mgebj vgebj (-2 = .) (-1 = .a)

// Sibling information
gen sibl = . 
replace sibl = 0 if geschw==2
recode nums numb (-3=.) (-2 = .) (-1 = .a)
replace nums = 0 if nums == . & numb < .
replace numb = 0 if numb == . & nums < .
replace numb = 0 if numb == . & nums == . & inlist(geschw,1,2,-2)
replace nums = 0 if nums == . & numb == 0 & inlist(geschw,1,2,-2)
replace sibl = numb + nums 
replace sibl = 0 if sibl == . & geschw == 2

// top-coding sibling
// top-code sibling numbers at 10 siblings max
// gen sibl_coded = min(sibl,10) if sibl < .


// rename variables for later pooling
rename vgebj fathbrth 
rename mgebj mothbrth
gen mothGerm = inlist(morigin,1,7) if morigin > 0 & morigin < .
gen fathGerm = inlist(vorigin,1,7) if morigin > 0 & morigin < .

// reconstruct some missing values in mothGerm and fathGerm using the migback variable from ppfad
replace mothGerm = 1 if migback == 1 // if there is no migration background, assume that mother was born in Germany
replace fathGerm = 1 if migback == 1 // if there is no migration background, assume that father was born in Germany
// shortcoming: the migback variable is partly (but not only) based on morigin and vorigin 

// born in germany
recode germborn (2 = 0) (1=1), gen(bornde)

rename gebjahr brth
recode sex (2=1) (1=0), gen(female)

// age
gen age = syear - brth 

// East and West - define by place of living of respondent in 1989 (!)
recode loc1989( 2 3 = 2 "West") (1 = 1 "East") (-2 = -2) (-1 = .b), gen(part)
// 43 missings
// count born abroad and in former eastern German territories to West
// estimate East / west based on sample membership
replace part = 2 if sampreg==1 & (part == -2 | part >= .) // west
replace part = 1 if sampreg==2 & (part == -2 | part >= .)  // east

// but if neither father nor mother was born in Germany we recode "part" to missing
replace part = . if mothGerm!=1 & fathGerm!=1

// keep only relevant variables
gen inty = syear

// weights
gen sw = phrf

isid pid

gen data = 1
keep pid age inty sex sibl fathbrth mothbrth bornde mothGerm fathGerm cabi vabi mabi brth part female data sw psample

// recode mother's father's year of birth
recode * (-2 = .) (-1 -3 = .a) 

tempfile SOEP
save `SOEP', replace


/*----------------------------------------------------
 
 III) Pool NEPS and SOEP in one dataset

 ----------------------------------------------------*/

use `NEPS', clear
append using `SOEP'
// complete labels for survey variable
lab def data 0 "NEPS 2011/2012" 1 "SOEP 2012" , modify
lab val data data

// We treat the various surveys as random samples
// Check weights - they need to be normalized later
tabstat sw, by(data) stats(mean sd)

fre mothGerm 

lab var data "Data"
lab var part "East-West Germany (dataset specific, . if both parents were born abroad)"
lab var vabi "Father Abitur"
lab var mabi "Mother Abitur"
lab var sibl "Siblings (uncoded)"
lab var sw "Survey weights"
lab var age "age at interview"
lab var female "female"
lab var cabi "Respondent Abitur"
lab var brth "Year of birth"
lab var sex "Sex"
lab var fathbrth "Father year of birth" 
lab var mothbrth "Mother year of birth"


// Save data
save "${tempDir}/00_retrospective_data", replace


exit

