/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Skopek, Jan and Leopold, Thomas (2020). Educational Reproduction in Germany: 
  A Prospective Study Based on Retrospective Data. In: Demography.
  
  01_fertility_data.do 
  
  Prepare fertility database including various external fertility datasets. 
  
  Fertility data surveys: DEAS (German Ageing Survey, Wave 1996, 2002, 2008, 2011), 
  ALLBUS (General Social Survey,   cumulated version + ALLBUS 2014),
  and European Social Survey (ESS, round 3). 
  
  File calls sub-do files in 01_fertility_data folder. 
  
  
  Produces 01_fertility_data.dta in temp folder, a dataset that includes harmonized 
  fertility data from all surveys above for the cohorts 1930–1950. 
  
  ------------------------------------------------------------------------------
------------------------------------------------------------------------------*/



* define cohort range
glo cohort_min = 1930 
glo cohort_max = 1950 


/*------------------------------------------------------------------------------

  1) Cumulated ALLBUS Data
  
------------------------------------------------------------------------------*/


* call sub-do file for preparing cumulated ALLBUS data
do 01_fertility_data/01a_KumALLBUS-data-prep.do

* load prepared data
use "${tempDir}/00_kum_Allbus.dta", clear

drop if mi(nofchildren, CASMIN)

keep if inrange(birth,${cohort_min},${cohort_max})

// restrict to persons born in DE (or for those surveyed before 1991, those who have german citizenship)
replace borninde = 1 if gercit == 1 & borninde == -1
keep if borninde == 1

// code education
recode CASMIN (1 2 4 = 1 "low") (3 5 6 7 = 2 "med") (8 9 = 3 "high"), gen(isced)

recode CASMIN (1/5=0) (6/9=1), gen(abi)

// code cohorts
egen bgrp = cut(birth) , at(1929 1935 1940 1946 1951) icodes label

// number of children
gen zero = nofchildren==0

gen measurement = 2 // means: "bio+social children"

rename V1740 weight

keep id syear zero abi nofchildren isced bgrp sex part weight birth measurement age 
tempfile kumallb
save `kumallb'


/*------------------------------------------------------------------------------

  2) Allbus 2014 (not being part of the cumulated file)
  
------------------------------------------------------------------------------*/

do 01_fertility_data/01b_ALLBUS-2014-data-prep.do
use "${tempDir}/00_Allbus_2014.dta", clear

drop if mi(isced)
drop if mi(zerobio)
* keep if inrange(birth,1930,1945)
keep if inrange(birth,${cohort_min},${cohort_max})

// code cohorts
egen bgrp = cut(birth) , at(1929 1935 1940 1946 1951) icodes label

rename V870 weight
rename zerobio zero
gen measurement = 1 // means: "bio children" (allbus 2014 talks about "own" children!)
keep id syear zero nofchildren abi isced bgrp sex part weight birth measurement age 
tempfile allb2014
save `allb2014'

use `kumallb', clear
append using `allb2014'

rename syear allbus
gen syear = allbus

tempfile allb
save `allb'


/*------------------------------------------------------------------------------

  3) DEAS Data (1996, 2002, 2008, 2011)
  
------------------------------------------------------------------------------*/

do 01_fertility_data/01c_DEAS-1996-data-prep
do 01_fertility_data/01d_DEAS-2002-data-prep
do 01_fertility_data/01e_DEAS-2008-data-prep
do 01_fertility_data/01f_DEAS-2011-data-prep

foreach num of numlist 1996 2002 2008 2011 {
	use "${tempDir}/00_DEAS-`num'.dta", clear
	renvars, prefix("w`num'_")
	rename w`num'_fallnum fallnum
	gen DEAS =  w`num'_DEAS
	tempfile `num'
	save ``num''
}
use `1996', clear
foreach num of numlist 2002 2008 2011 {
	merge 1:1 fallnum using ``num'', nogen
} 

// 13.353 in total
count

// entry in wave
fre DEAS

// PREPARE 
// First sample - 1996
preserve
keep if DEAS == 1996 // 4838

gen nofchildren = w1996_nofchildren
gen numbiochild = w1996_numbiochild
gen numbiochildliv = w1996_numbiochildliv
gen age = w1996_alter_96
lab var age "age at first interview"
gen ageli = w1996_alter_96
lab var ageli "age at last interview (fertility data updated)"

// for those younger than 50 update child-information
foreach var of varlist nofchildren numbiochild numbiochildliv {
	replace `var' = w2002_`var' if w1996_alter_96 < 50 & !mi(w2002_`var')
	replace `var' = w2008_`var' if w1996_alter_96 < 50 & !mi(w2008_`var')
	replace `var' = w2011_`var' if w1996_alter_96 < 50 & !mi(w2011_`var')
	replace ageli = w2002_alter_02 if w1996_alter_96 < 50 & !mi(w2002_`var')
	replace ageli = w2008_alter_08 if w1996_alter_96 < 50 & !mi(w2008_`var')
	replace ageli = w2011_alter_11 if w1996_alter_96 < 50 & !mi(w2011_`var')
}
drop DEAS
drop w1996_nofchildren w1996_numbiochild w1996_numbiochildliv
renvars w1996_*, subst("w1996_" "")

rename w2011_isced_11 isced
replace isced = isced_96

drop stich

// restrict to born in Germany
keep if inlist(geburtsort, 1,2) // frühere Ostgebiete, heutige BRD

// East West - where usually lived the last 40 years
recode usualres40years (1 = 1 "East") (2 = 2 "West") (else=.), gen(part)

// drop cases not lived in the last 40 most of the time either in east or west germany
drop if part >= .

// drop some cases without educational level
drop if CASMIN >= .
// design weight
rename gew_m2 dweight

keep fallnum nofchildren numbio* part CASMIN E isced Chrt sex dweight DEAS birth age ageli
lab var part "lived up in East/west"
lab var nofchildren "Number of children (own or others)"
lab var numbiochild "Number of (identified) biological children"
lab var numbiochildliv "bio children who are identified have lived at least up to age 20"

tempfile 1996
save `1996'
restore

// PREPARE 
// Second sample - 2002
preserve
keep if DEAS == 2002 // 3084 (only basissample from 2002)

gen nofchildren = w2002_nofchildren
gen numbiochild = w2002_numbiochild
gen numbiochildliv = w2002_numbiochildliv
gen age = w2002_alter_02
lab var age "age at first interview"
gen ageli = w2002_alter_02
lab var ageli "age at last interview (fertility data updated)"

// for those younger than 50 update child-information
foreach var of varlist nofchildren numbiochild numbiochildliv {
	replace `var' = w2008_`var' if w2002_alter_02 < 50 & !mi(w2008_`var')
	replace `var' = w2011_`var' if w2002_alter_02 < 50 & !mi(w2011_`var')
	replace ageli = w2008_alter_08 if w2002_alter_02 < 50 & !mi(w2008_`var')
	replace ageli = w2011_alter_11 if w2002_alter_02 < 50 & !mi(w2011_`var')
}
drop DEAS
drop w2002_nofchildren w2002_numbiochild w2002_numbiochildliv
renvars w2002_*, subst("w2002_" "")

rename isced_02 isced

drop stich

// restrict to born in Germany
keep if inlist(geburtsort, 1,2) // frühere Ostgebiete, heutige BRD

// East West - where usually lived between 1949 and 1990years
recode res19491990 (1 = 1 "East") (2 = 2 "West") (else=.), gen(part)

// drop cases not lived in the last 40 most of the time either in east or west germany
drop if part >= .

// drop some cases without educational level
drop if CASMIN >= .
// design weight
rename igew_7 dweight

keep fallnum nofchildren numbio* part CASMIN E isced Chrt sex dweight DEAS birth age ageli
lab var part "lived up in East/west"
lab var nofchildren "Number of children (own or others)"
lab var numbiochild "Number of (identified) biological children"
lab var numbiochildliv "bio children who are identified have lived at least up to age 20"

tempfile 2002
save `2002'
restore

// PREPARE 
// Third sample - 2008
preserve
keep if DEAS == 2008 // 6205 (only basissample from 2008)

gen nofchildren = w2008_nofchildren
gen numbiochild = w2008_numbiochild
gen numbiochildliv = w2008_numbiochildliv
gen age = w2008_alter_08
lab var age "age at first interview"
gen ageli = w2008_alter_08
lab var ageli "age at last interview (fertility data updated)"

// for those younger than 50 update child-information
foreach var of varlist nofchildren numbiochild numbiochildliv {
	replace `var' = w2011_`var' if w2008_alter_08 < 50 & !mi(w2011_`var')
	replace ageli = w2011_alter_11 if w2008_alter_08 < 50 & !mi(w2011_`var')
}
drop DEAS
drop w2008_nofchildren w2008_numbiochild w2008_numbiochildliv
renvars w2008_*, subst("w2008_" "")

rename isced_08 isced
drop stich

// restrict to born in Germany
keep if inlist(geburtsort, 1,2) // frühere Ostgebiete, heutige BRD

// East West - where lived before reunification
recode wherelived (1 = 1 "East") (2 = 2 "West") (else=.), gen(part)

// drop cases not lived in the last 40 most of the time either in east or west germany
drop if part >= .

// drop some cases without educational level
drop if CASMIN >= .

// design weight
rename intb08a7 dweight

keep fallnum nofchildren numbio* part CASMIN E isced Chrt sex dweight DEAS birth age ageli
lab var part "lived up in East/west"
lab var nofchildren "Number of children (own or others)"
lab var numbiochild "Number of (identified) biological children"
lab var numbiochildliv "bio children who are identified have lived at least up to age 20"

tempfile 2008
save `2008'
restore

use `1996', clear
append using `2002'
append using `2008'

rename fallnum id 
gen syear = DEAS

drop if mi(nofchildren)
gen zero = nofchildren == 0
gen zerobio = numbiochild == 0
drop if mi(isced)

// restrict sample
* keep if inrange(birth,1930,1945)
keep if inrange(birth,${cohort_min},${cohort_max})


// restrict to persons born in DE (or for those surveyed before 1991, those who have german citizenship)
// (already done)

// at least age 45 at time of interview (avoid right-censoring in fertility)
drop if ageli < 45

// code cohorts
egen bgrp = cut(birth) , at(1929 1935 1940 1946 1951) icodes label

rename dweight weight

gen measurement = 3 // "both bio and bio+social"

recode CASMIN (1/5=0) (6/9=1) (else=.), gen(abi)

// IMPORTANT
// replace zero with zerobio : we cannot distinguish that in other surveys (so we assume we deal with biological children)
// that leads otherwise to strong survey effect of DEAS. 
replace nofchildren = numbiochild
replace zero = zerobio
keep id syear zero abi nofchildren isced bgrp sex part weight birth DEAS age ageli  measurement

tempfile deas
save `deas'


/*------------------------------------------------------------------------------

  4) ESS (Round 3, 2006)
  
------------------------------------------------------------------------------*/

do 01_fertility_data/01h_ESS3-data-prep.do
use "${tempDir}/00_ESS3-2006.dta", clear

// restrict sample
* keep if inrange(birth,1930,1945)
keep if inrange(birth,${cohort_min},${cohort_max})

// restrict to born in Germany
keep if borninde == 1
// education 
recode eisced (1 2 = 1 "low (0-2)") ///
				(3 4 5 = 2 "med (3-4)") ///
				(6 7 = 3 "high (5-6)"), gen(isced)
	drop if mi(isced)

recode edlvade (1/4=0) (5/8=1), gen(abi)	
drop if mi(nofchildren) 

gen zero = nofchildren==0
gen measurement = 2 

gen ESS = 2006
gen syear = 2006
// code cohorts
egen bgrp = cut(birth) , at(1929 1935 1940 1946 1951) icodes label

rename dweight weight
rename idno id
keep id syear zero abi nofchildren  isced bgrp sex part weight birth ESS age measurement 
tempfile ess
save `ess'

/*------------------------------------------------------------------------------

  5) Merge all data 
  
------------------------------------------------------------------------------*/

use `allb', clear
append using `deas'
append using `ess'

// gen a variable indicating survey
gen surveyid = allbus
replace surveyid = 10000 + DEAS if !mi(DEAS)
replace surveyid = 30000 + ESS if !mi(ESS)

gen survey = ""
foreach num of numlist 1982 1984 1991 1992 2000 2002 2004 2006 2008 2010 2012 2014 {
	replace survey = "ALLB `num'" if surveyid == `num'
}
foreach num of numlist 1996 2002 2008 {
	replace survey = "DEAS `num'" if surveyid == 1`num'
}
replace survey = "ESS 2006" if surveyid==32006
// generate a clear identifyer
encode survey , gen(data)


recode birth (1930/1935 = 0 "30/35") (1936/1940 = 1 "36/40") (1941/1945=2 "41/45") (1946/1950 = 3 "46/50"), gen(coh)
lab var abi "Abitur"
lab var part "Part"
lab var coh "Cohort"

// drop cases with missing values on abitur (implicitly drops GGS) and other variables
misstable sum coh abi zero part weight
keep if !mi(coh, abi, zero, part, weight)

// 
lab def measurement 1 "Bio children" 2 "bio+social" 3 "both bio & bio+social"
lab val measurement measurement

// standardize/normalize weights within surveys
by survey, sort: egen sw = mean(weight)
gen weightn = weight/sw
by survey, sort: egen swn = total(weightn)
// this standardized weight ensures that all survey provide information to the same proportion
fre survey
fre survey [aw=weightn]
// more weight is naturally given to larger sample sizes (we expect more precise estimates)

// generate a harmonized age variable (floor decimals)
replace age = floor(age)

keep coh birth abi zero part weightn sex measurement data nofchildren  age 

//
// Save harmonized dataset 
// 
save "${tempDir}/01_fertility_data", replace


