/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  
  Variables needed: 

- sex
- Children yes/no
- Number of biological children
- Educational level
- Birth date / Cohort
- Born in Germany
- where lived before reunification
- interview date
- weights

- stichprobe (update 1996 sample by panel data) -> stich
- part_96
  
  Documentation on the German Ageing Survey can be found here: 
  
  http://www.dza.de/fdz/deutscher-alterssurvey.html (english pages available)
  
  Engstler, H. and A. Motel-Klingebiel (2010). Datengrundlagen und 
		Methoden des Deutschen Alterssurveys (DEAS). In: Motel-Klingebiel, A., 
		Wurm, S., and Tesch-Römer, C. (eds), Altern im Wandel. Befunde des Deutschen 
		Alterssurveys (DEAS). Stuttgart: Kohlhammer, S. 34-60.
		
  Mahne, K. and  H. Engstler (2010). Deutscher Alterssurvey (DEAS). 
		Kurzbeschreibung des Datensatzes DEAS2008 Version 2.
		
  Motel-Klingebiel, A. et al. (2010). GERMAN AGEING SURVEY (DEAS): THE SECOND 
		HALF OF LIFE. Research Instruments of the Third Wave. German Centre of 
		Gerontology. http://www.dza.de/fileadmin/dza/pdf/Diskussionspapier_Nr_52.pdf

  
  Note: The original scientific use file contains coarsed and categorized dates 
		for birth of children and grandchildren for reasons of disclosure control. 
		However, a correct estimation of timing of grandparenthood requires very 
		precise data. Hence, for the purpose of our study, we obtained the 
		original values for date of birth variables from the data center of 
		the DZA. 
  
------------------------------------------------------------------------------
------------------------------------------------------------------------------*/


global sufdata "../../DEAS-Data/SUF_DEAS2008_2_deen.dta"
// reference to the file containing detailed birth data of children and grandchildren

set more off

// config 
// run config

* load original SUF data file
use "${data_deas_2008}", clear

/*-----------------------------------------
  Restrict to cross-section 2008. 
-----------------------------------------*/

// Restriction to cross-sectional sample in 2008 (Basisstichprobe B2008)
// keep if stich==3

// Keep older samples for follow up

rename x1 sex
rename x2_3 birth // view cases grouped to 1915, negligible
rename x325 geburtsort
* item for number of children
recode x300 (95=0), gen(nofchildren) // censored at 9+ children (only few cases)


* Lived in which part of Germany prior to reunification 
rename x328 wherelived 
* Where grew up (until age of 16)
rename  x327 wheregrewup


// up to child 8 is asked
gen numbiochild = 0 // number of reported biological children
foreach num of numlist 1/8 {
	replace numbiochild = numbiochild + 1 if inlist(x303`num',1,2) | x303a`num'==2 | x303b`num' == 2 
}

/*-----------------------------------------
  Recover original birth data. 
-----------------------------------------*/

// The original scientific use file contains coarsed and categorized dates for birth 
// of children and grandchildren for reasons of disclosure control. 
// For the purpose of our study, we obtained from the data center of the DZA 
// the original not manipulated date of birth variables. 

// Note: variable "fallnum" is the person identifier. 

// Replace not-anonymized birth dates. 
* 1) load add-on data (original birth dates)
preserve 
	use "${data_deas_2008_exact_birthdates}", clear
	// remove data from previous samples
	merge 1:1 fallnum using "${data_deas_2008}", assert(match) keepusing(stich)
	// keep if stich==3
	
	renvars x3041-x316d28o, pref(EXACT_)
	tempfile exact
	save `exact'
restore
* 2) merge add-on data
merge 1:1 fallnum  using `exact', nogen

* 3) replace anonymized birth date data with exact data
* (child 1-4)
foreach var of varlist x3041 x3042 x3043 x3044 {
	order EXACT_`var', before(`var') 
	rename `var'  __`var' 
	rename EXACT_`var' `var'
}
* (child 5-8)
foreach num of numlist 5/8 {
	rename EXACT_x304`num' x304`num'
	order x304`num', before(x304`num'kat)
	drop x304`num'kat
}

* "Single" grandkids ("Einzelenkel", uncategorized variables)
foreach var of varlist x316d1? x316d2?? {
	order EXACT_`var', before(`var') 
	rename `var'  __`var' 
	rename EXACT_`var' `var'
}

* "Einzelenkel", "Basisenkel" (categorized variables)
* replace categorized variables by original variables 
* d x316d1? x316d1?kat x316d2?*
foreach var of varlist x316???kat x316????kat {
	local name: subinstr local var "kat" ""
	di "`name'"
	if "`name'" != "`var'" {
		gen `name' = EXACT_`name'
		order `name', before(`var')
		local label: variable label `var'
		local label: subinstr local label ", kategorisiert" ""
		lab var `name' "`label'"
		drop `var'
	} 
	drop EXACT_`name'
}

* Remainder
order EXACT_x316d21k-EXACT_x316d21o, after(x316g21j)
renvars EXACT_x316d21k-EXACT_x316d21o, subst("EXACT_" "")
order __*, last

drop __*

// we do not have the exact death date for children
// take the middle value from the categories
foreach num of numlist 1/8 {
	gen x315`num' = x315`num'kat
	recode x315`num' (1 = 1945) (2 = 1955) (3 = 1965) (4 = 1975) (5 = 1985) (6 = 1995) (7 = 2004) 
}

// Note: number of reported bio children may be biased towards zero since 
//       not specified missings in family relationship are treated as non-bio child.

// Living biological children (i.e. children who are still living or lived at least to 20)
gen numbiochildliv = 0 
foreach num of numlist 1/8 {
	replace numbiochildliv = numbiochildliv + 1 if (inlist(x303`num',1,2) | x303a`num'==2 | x303b`num' == 2 ) /// bio child
							 & (x304a`num'==1 | (x304a`num'==2 & (x315`num' - x304`num')>=20))
}


	
// CASMIN
/*
3b Hochschulabschluss
3a Fachhochschulabschluss
2c_voc Fachhochschulreife/Abitur und berufliche Ausbildung
2c_gen Fachhochschulreife/Abitur ohne berufliche Ausbildung
2a Mittlere Reife und berufliche Ausbildung
2b Mittlere Reife ohne berufliche Ausbildung
1c Hauptschulabschluss und berufliche Ausbildung
1b Hauptschulabschluss ohne berufliche Ausbildung
1a kein Abschluss
*/
desc x26-x31
// RULE:
// 	if x26 = in einem anderen land; kein schulbesuch; verweigert, weiß nicht
// 	then skip x27
recode x27 (1 9 = 1 "kein Abschluss") ///
		   (2 4 = 2 "HS" ) ///
		   (3 5 = 3 "RS")  ///
		   (6 7 = 4 "ABI") ///
		   (8 = 5 "sonstiges") ///
		   (-1 = .) ///
		   (97 98 = ".a"), gen(CASMIN_gen)

// Teil|fach|ar|bei|ter, der (DDR): angelernter Arbeiter 
// (ohne abgeschlossene Ausbildung).
// Teilfacharbeiter => keine Ausbildung, eher Lehrgang
recode x30 (1 8 = 1 "keine BA") ///
		   (2 3 4 = 2 "BA") ///
		   (5 = 3 "FH") ///
		   (6 = 4 "Uni") ///
		   (7 = 5 "sonstiges") ///
		   (-1 = .) /// 
		   (97 = .a), gen(CASMIN_voc)
replace CASMIN_voc = 1 if x31==1 & CASMIN_voc >= .
replace CASMIN_voc = 2 if x31==2 & CASMIN_voc >= .
replace CASMIN_voc = 2 if x31==3 & CASMIN_voc >= .
replace CASMIN_voc = 3 if x31==4 & CASMIN_voc >= .


// combine
gen CASMIN = -1
lab def CASMIN ///
9 "3b Hochschulabschluss" ///
8 "3a Fachhochschulabschluss" ///
7 "2c_voc Fachhochschulreife/Abitur und berufliche Ausbildung" ///
6 "2c_gen Fachhochschulreife/Abitur ohne berufliche Ausbildung" ///
5 "2a Mittlere Reife und berufliche Ausbildung" ///
4 "2b Mittlere Reife ohne berufliche Ausbildung" ///
3 "1c Hauptschulabschluss und berufliche Ausbildung" ///
2 "1b Hauptschulabschluss ohne berufliche Ausbildung" ///
1 "1a kein Abschluss" ///
.b "nicht bestimmbar" ///
, modify

lab val CASMIN CASMIN
replace CASMIN = 9 if CASMIN_voc == 4
replace CASMIN = 8 if CASMIN_voc == 3
replace CASMIN = 7 if CASMIN_voc == 2 & CASMIN_gen == 4
replace CASMIN = 6 if CASMIN_voc == 1 & CASMIN_gen == 4
replace CASMIN = 5 if CASMIN_voc == 2 & CASMIN_gen == 3
replace CASMIN = 4 if CASMIN_voc == 1 & CASMIN_gen == 3
replace CASMIN = 3 if CASMIN_voc == 2 & CASMIN_gen == 2
replace CASMIN = 2 if CASMIN_voc == 1 & CASMIN_gen == 2
replace CASMIN = 1 if CASMIN_voc == 1 & CASMIN_gen == 1
// special cases: 
// no school degree but BA => define as "HS mit BA"
replace CASMIN = 3 if CASMIN_gen==1 & CASMIN_voc==2 & CASMIN==-1
// other school degree and BA => define as "HS mit BA"
replace CASMIN = 3 if CASMIN_gen==5 & CASMIN_voc==2 & CASMIN==-1
// "die Schule ohne Abschluss verlassen" & 
// "die Pflichtschule mit Abschluss beendet" => dito
replace CASMIN = 3 if inlist(x28,1,2) & CASMIN_voc==2 & CASMIN==-1
// "eine weiterführende Schule mit Abschluss beendet" => RS + BA
replace CASMIN = 5 if inlist(x28,3) & CASMIN_voc==2 & CASMIN==-1
// "weiß nicht / verweigert" => assign Hauptschule!
replace CASMIN = 3 if CASMIN_gen == .a & CASMIN_voc==2 & CASMIN==-1

// keine BA & kein schulabschluss
replace CASMIN = 1 if x28==1 & CASMIN_voc==1 & CASMIN==-1
replace CASMIN = 2 if x28==2 & CASMIN_voc==1 & CASMIN==-1
replace CASMIN = 4 if x28==3 & CASMIN_voc==1 & CASMIN==-1

// sonstige Ausbildung (kodiere als keine Berufsausbildung)
replace CASMIN = 1 if x28==1 & x31==5 & CASMIN==-1
replace CASMIN = 2 if x28==2 & x31==5 & CASMIN==-1
replace CASMIN = 4 if x28==3 & x31==5 & CASMIN==-1

replace CASMIN = 1 if CASMIN_gen == 1 & CASMIN_voc == 5 & CASMIN == -1
replace CASMIN = 2 if CASMIN_gen == 2 & CASMIN_voc == 5 & CASMIN == -1
replace CASMIN = 4 if CASMIN_gen == 3 & CASMIN_voc == 5 & CASMIN == -1
replace CASMIN = 6 if CASMIN_gen == 4 & CASMIN_voc == 5 & CASMIN == -1

// if ausbildung was skipped
replace CASMIN = 1 if CASMIN_gen == 1 & CASMIN_voc == . & CASMIN == -1
replace CASMIN = 2 if CASMIN_gen == 2 & CASMIN_voc == . & CASMIN == -1
replace CASMIN = 2 if CASMIN_gen == 2 & CASMIN_voc == .a & CASMIN == -1
replace CASMIN = 4 if CASMIN_gen == 3 & CASMIN_voc == . & CASMIN == -1
replace CASMIN = 6 if CASMIN_gen == 4 & CASMIN_voc == . & CASMIN == -1

replace CASMIN = 1 if x28==1 & x31==-1 & CASMIN==-1
replace CASMIN = 2 if x28==2 & x31==-1 & CASMIN==-1
replace CASMIN = 4 if x28==3 & x31==-1 & CASMIN==-1
replace CASMIN = 4 if inlist(x28,8,9) & x31==-1 & CASMIN==-1

// kein schulbesuch
replace CASMIN = 1 if x26==6 & CASMIN==-1

// set rest to not determinable
replace CASMIN = .b if CASMIN==-1

drop CASMIN_*

lab var CASMIN "CASMIN-classes"
fre CASMIN

recode CASMIN (1 2 4 = 0 "low") /// no degree, hauptschule ohne BA, realschule ohne BA
		   (3 = 1 "lower voc") /// hauptschule mit BA
		   (5 =2 "medium voc") /// realschule mit BA
		   (6 7 = 3 "high voc") /// abitur +/- BA
		   (8 9  = 4 "university") /// tertiary, university
		   , gen(E)
// collapse high voc and university
capt drop E
recode CASMIN (1 2 4 = 0 "low") /// no degree, hauptschule ohne BA, realschule ohne BA
		   (3 = 1 "lower voc") /// hauptschule mit BA
		   (5 =2 "medium voc") /// realschule mit BA
		   (6 7 8 9 = 3 "high voc/university") /// abitur +/- BA, tertiary, university
		   , gen(E)		   
recode birth 	(1914/1925.9 = 1 "1914-1926)") ///
			    (1926/1935.9 = 2 "1926-1936)") /// 
				(1936/1944.9 = 3 "1936-1945)") ///
				(1945/1960 = 4 "1945-1960") ///
				(else = .), gen(Chrt)		  

// collapse cohort categories
recode Chrt (1 2 = 1) (3 4 = 2),  gen(Chrt2) 

// Restrict dataset to needed variables
keep fallnum sex stich intb08a7 intb08d7 nat_ewo_08 alter_08 CASMIN birth nofchildren numbiochild numbiochildliv E CASMIN ///
		birth Chrt Chrt2 geburtsort	wherelived wheregrewup isced_08


gen DEAS = 2008
/*-----------------------------------------
  Save data
-----------------------------------------*/
save "${tempDir}/00_DEAS-2008.dta", replace




