/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Skopek, Jan and Leopold, Thomas (2020). Educational Reproduction in Germany: 
  A Prospective Study Based on Retrospective Data. In: Demography.
  
  02_data_fusion.do
  
  Adds estimated zero-fertility (childlessness) to retrospective data. 
  
  Use the fertility database to estimate zero-fertility by a three-way interaction of
	- East/West, 
	- Cohort (categorical), and
	- Gender.

  Control for survey effects and gender specific age effects. 
  Predict based on the average survey and age 50+. 

  Finally, add fertility data to the retrospective dataset.
  
  Outputs:
  - Table B1 (overview of pooled fertility data)
  ------------------------------------------------------------------------------
------------------------------------------------------------------------------*/


/*------------------------------------------------------------------------------

  1) Estimate zero-fertility
  
------------------------------------------------------------------------------*/

use "${tempDir}/01_fertility_data", clear

// overview to datasets
fre data  // Keep in mind, that GGS data is not included due to missing educational information

// split by east and west
fre part 

/*---------------------------------------------------------------
	Table B1 – Overview of Pooled Fertility Data
---------------------------------------------------------------*/
// descriptives for the fertility surveys
preserve
	gen east = part == 1
	gen female = sex == 2
	foreach var of varlist east abi zero female {
		replace `var' = 100*`var'
	}
	// total column
	tabstat female age birth east abi zero , f(%9.0f) 
	count 
	// table
	gen minbirth = birth
	gen maxbirth = birth
	gen N = 1
	collapse (count) N (mean) age birth east abi zero female (min) minbirth (max) maxbirth, by(data) 
	format %9.0f minbirth maxbirth age female  birth  east abi zero 
	
	log using "${logDir}/Table_B1.smcl", replace

	li data N female age birth  minbirth maxbirth  east abi zero ,  clean noobs
	
	log close 
	
restore

count
fre part 

// Estimate probability of zero fertility
tabstat weightn, by(data) stats(mean sd)
tabstat zero, by(data) stats(mean sd)

// estimate zero fertility by East and West and dataset
logit zero i.part##i.data [pw=weightn]
margins data#part 
marginsplot , xlabel(, labsize(vsmall) angle(45)) 

// create age cats to account for right censoring 
recode age (50/max=0 "50+") (41/49=1 "41-49") (min/40 = 3 "<=40"), gen(agecat)

// Estimate zero fertility - control for data and age group
logit zero (i.coh i.abi)##i.part##i.sex i.data i.agecat i.agecat#i.sex [pw=weightn]
est store zero
// plot survey effects
margins data 
marginsplot , xlabel(, labsize(vsmall) angle(45)) 
// there are some survey effects, DEAS 2002/08 are outliers

// est table
est table zero, star b(%9.3f)

// predict zero-fertility, hold survey at the mean and setting age to at least 50
// for that re-estimate the model in a slightly different specification
// by centering the data dummies at the mean
tab data, gen(data_)
center data_1-data_16 [aw=weightn], replace
logit zero (i.coh i.abi)##i.part##i.sex c_data_2-c_data_16 i.agecat [pw=weightn]
est store zero2



// check for identity of results (except for the constant, which will be different)
est table zero zero2, star b(%9.3f)

// estimate a more precise model not based on coh, but based on years
logit zero (c.birth i.abi)##i.part##i.sex c_data_2-c_data_16 i.agecat [pw=weightn]
est store zero3

// set all dummies at zero (average survey)
foreach num of numlist 1/16 {
	replace c_data_`num' = 0
}
// set age cat to 50+
replace agecat = 0
// predict at the average survey
est restore zero2
predict z

// predict more precise (based on the model with linear time trend)
est restore zero3
predict ztrend

table birth abi part, c(mean z) f(%9.2f)
table coh abi part, c(mean z) f(%9.2f)
// show in %
gen _z = z*100


/*-----------------------------------------------------------
// Table 3 (columns of childlessness)
// (but see 10_educational_reproduction for full Table 3!)
-----------------------------------------------------------*/
est restore zero2 

* point estimations and CIs
margins, over(sex part coh abi) ///
	at(c_data_2=0 c_data_3=0 c_data_4=0 c_data_5=0 c_data_6=0 ///
	   c_data_7=0 c_data_8=0 c_data_9=0 c_data_10=0 c_data_11=0 ///
	   c_data_12=0 c_data_13=0 c_data_14=0 c_data_15=0 c_data_16=0 ///
	   agecat=0) post
esttab , b(%9.3f) ci(%9.3f) nostar label

* Compact table
// MEN
table coh abi part if sex==1, c(mean _z) f(%9.1f)
// WOMEN
table coh abi part if sex==2, c(mean _z) f(%9.1f)

/*-----------------------------------------------------------*/



/*------------------------------------------------------------------------------

  1) Match zero-fertility data to retrospective data
  
------------------------------------------------------------------------------*/

collapse (mean) z (mean) ztrend, by(sex birth abi part) // weighting not necessary since z constant within strata
gen mothbrth = birth if sex==2
gen fathbrth = birth if sex==1
gen mabi = abi if sex == 2
gen vabi = abi if sex == 1

preserve 
	keep if mothbrth < .
	rename z wz
	rename ztrend wztrend
	tempfile women
	save `women'
restore
preserve 
	keep if fathbrth < .
	rename z mz
	rename ztrend mztrend

	tempfile men
	save `men'
restore


// Merge zero-fertility data to retrospective dataset
use "${tempDir}/00_retrospective_data", clear
merge n:1 mabi mothbrth part using `women', assert(master matched) keep(master matched) nogen keepusing(wz wztrend)
merge n:1 vabi fathbrth part using `men', assert(master matched) nogen keepusing(mz mztrend)
lab var wz "Women zero fertility (prob)"
lab var mz "Men zero fertility (prob)"
lab var wztrend "Women zero fertility (prob), trend model"
lab var mztrend "Men zero fertility (prob), trend model"

// matching results
fre wz mz

save "${tempDir}/02_data_fusion", replace
