/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Skopek, Jan and Leopold, Thomas (2020). Educational Reproduction in Germany: 
  A Prospective Study Based on Retrospective Data. In: Demography.
  
  03_startingsample_respondents.do
  
  Calibrate samples of parent cohorts by 
	- East/West and 
	- Gender
	
  We create first offspring samples and from that parent samples. 

  Output: 
  - Table 1 (Starting Sample of Respondents)
  - Figure A1 (Respondents and their parents)
 ------------------------------------------------------------------------------
------------------------------------------------------------------------------*/ 
  

use "${tempDir}/02_data_fusion", clear

// do some general exclusions on the level of respondents
* drop cases with missing information on birth date
drop if mi(brth)
* drop cases with missing information on siblings
drop if mi(sibl)
* drop cases with missing information on respondents education
drop if mi(cabi)
* drop cases with missing information on part of Germany
drop if mi(part)
* drop cases with missing information on both parents date of birth
drop if mi(mothbrth) & mi(fathbrth)
* drop cases with missing information on both parents education
drop if mi(vabi) & mi(mabi)
* drop cases with missing information on both parents place of birth
drop if mi(mothGerm) & mi(fathGerm)



* drop some cases with a very unplausible age distance to mother
drop if brth - mothbrth < 15
* drop some cases with a very unplausible age distance to father
drop if brth - fathbrth < 15
* cut SOEP to the same birth cohorts as NEPS 1944 - 1988
drop if data == 1 & !inrange(brth,1944,1988)

/* we could impose also an upper truncation at 60 years age distance 
 - does not change the results
// gen age distance to mother
gen mdist = brth - mothbrth 
// and to father
gen fdist = brth - fathbrth 
drop if mdist > 60 & mdist < .
drop if fdist > 60 & fdist < .
*/

// case numbers - starting sample of respondents
fre data 

// normalize weights by survey 
by data, sort: egen msw = mean(sw)
by data, sort: gen swn = sw/msw
// replace the sw with normalized weight
replace sw = swn
tabstat sw, by(data)
drop msw swn

// unweighted
tabstat cabi brth age sibl mothbrth fathbrth mothGerm fathGerm mabi vabi , by(data)  stats(mean) f(%9.2g)
// weighted
tabstat cabi brth age sibl mothbrth fathbrth mothGerm fathGerm mabi vabi [aw=sw], by(data)  stats(mean) f(%9.2g)

/*------------------------------------------------------------------
	Table 1 Starting Sample of Respondents
------------------------------------------------------------------*/

log using "${logDir}/Table_1-Starting-Sample.smcl", replace

tabstat brth age sibl cabi bornde mothbrth mothGerm mabi fathbrth fathGerm vabi [aw=sw], by(data)  stats(mean sd min max) f(%9.2g)

log close
/*------------------------------------------------------------------*/

// inter-percentile (5-95) range for parents birth years
tabstat mothbrth fathbrth [aw=sw], stats(p5 p95) f(%9.0f)

// gen age distance to mother
gen mdist = brth - mothbrth 
// and to father
gen fdist = brth - fathbrth 

// choose 43 as upper limit
tabstat mdist fdist, stats(p99) // 99% of mothers were 43 or younger at birth of respondent. 
// fathers
fre fdist, all

// Illustrate the problem of cohort identification with a figure
preserve 
	keep if inrange(brth, 1970, 1980)
	keep if !mi(mothbrth, fathbrth)
	gen n = sw
	collapse (sum) n, by(brth)
	tempfile respondents
	save `respondents'
restore

// Mothers 
preserve 
	keep if inrange(brth, 1970, 1980)
	gen n = sw
	collapse (sum) n, by(mothbrth)
	rename mothbrth brth
	gen mothers = 1
	tempfile mothers
	save `mothers'
restore
// Fathers 
preserve 
	keep if inrange(brth, 1970, 1980)
	gen n = sw
	collapse (sum) n, by(fathbrth)
	rename fathbrth brth
	gen fathers = 1
	tempfile fathers
	save `fathers'
restore
	
//
preserve
	use `respondents', clear
	append using `mothers'
	append using `fathers'
	
	// here we see the mother generation is not representative
	replace brth = brth-.8 if fathers==1
	replace brth = brth+.8 if mothers==1
	li 
	twoway (bar n brth if fathers==1, base(0) barwidth(.5)) (bar n brth if mothers==1,base(0) barwidth(.5)) (bar n brth if mothers==. & fathers==., barwidth(.5)) , ///
			scheme(s1color) xlabel(1900(5)1980, labsize(small) angle(45)) title("")  ///
			legend(lab(1 "Reported fathers") lab(2 "Reported mothers") lab(3 "Respondents") ring(0) pos(11) row(3) size(small)) ///
			xtitle(Year) ytitle("Sample size") 
restore

/*------------------------------------------------------------------

Figure A1. Respondents and their parents.

------------------------------------------------------------------*/

// Illustrate the problem of cohort identification with a figure
preserve 
	keep if inrange(brth, 1944, 1988)
	keep if !mi(mothbrth, fathbrth)
	gen n = sw
	collapse (sum) n, by(brth)
	tempfile respondents
	save `respondents'
restore

// Mothers 
preserve 
	keep if inrange(brth, 1944, 1988)
	gen n = sw
	collapse (sum) n, by(mothbrth)
	rename mothbrth brth
	gen mothers = 1
	tempfile mothers
	save `mothers'
restore
// Fathers 
preserve 
	keep if inrange(brth, 1944, 1988)
	gen n = sw
	collapse (sum) n, by(fathbrth)
	rename fathbrth brth
	gen fathers = 1
	tempfile fathers
	save `fathers'
restore
	
//
preserve
	use `respondents', clear
	append using `mothers'
	append using `fathers'
	
	// here we see the mother generation is not representative
	replace brth = brth-.8 if fathers==1
	replace brth = brth+.8 if mothers==1
	li 
	twoway (bar n brth if fathers==1, base(0) barwidth(.5) col(blue)) ///
		   (bar n brth if mothers==1,base(0) barwidth(.5) col(cranberry)) ///
		   (bar n brth if mothers==. & fathers==., barwidth(.5) col(green)) , ///
			scheme(s1color) xmtick(1870(5)1990) xlabel(1870(10)1990, labsize(small) angle(45)) title("")  ///
			legend(lab(1 "Reported fathers") lab(2 "Reported mothers") lab(3 "Respondents") ring(0) pos(11) row(3) size(small)) ///
			xtitle(Year) ytitle("Sample size") 
	graph export "${logDir}/Figure_A1.pdf", replace
restore


// save data
save "${tempDir}/03_startingsample_respondents", replace
