/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Skopek, Jan and Leopold, Thomas (2020). Educational Reproduction in Germany: 
  A Prospective Study Based on Retrospective Data. In: Demography.
  
  04_parent_samples.do 
  
  Based on the starting sample of respondents, create anchor samples for parents.
  
  Output: 
	- Table 2 (offspring samples)
	- Figure 2 (educational attainment in G1 and G2)
	- Figure A2 (Male and female target cohorts and their offspring after adjustment)
	- Figure A3 (comparison of fertility rates with official rates)
  ------------------------------------------------------------------------------
------------------------------------------------------------------------------*/


use "${tempDir}/03_startingsample_respondents", clear

count // 28,526
// check case numbers
assert _N==28526

fre data // 59% SOEP


lab def anchor 1 "Fathers" 2 "Mothers", modify


/*----------------------------------------------------
 
 Anchor sample for mothers

 ----------------------------------------------------*/

preserve 
	// keep only mothers born in Germany during 1930-45
	keep if mothGerm == 1

	// keep only a certain cohort range of mothers
	keep if inrange(mothbrth, 1930, 1950)

	// drop some few cases with missing information on education
	drop if mi(mabi)

	// there should be no missing values left over
	misstable sum mothbrth mabi cabi brth sibl part bornde female wz* sw data age

	keep mothbrth fathbrth mabi cabi brth sibl part bornde female wz* sw data age vabi

	gen anchor = 2 // mothers
	lab val anchor anchor 
	lab var anchor "Anchor sample"
	
	// normalize weights by survey 
	by data, sort: egen msw = mean(sw)
	by data, sort: gen swn = sw/msw
	// replace the sw with normalized weight
	replace sw = swn
	tabstat sw, by(data)
	drop msw swn
	
	// childlessness
	rename wz z
	rename wztrend ztrend

	// order 
	order anchor mothbrth fathbrth mabi vabi cabi brth sibl part bornde female z ztrend sw data age 
	rename fathbrth par2brth
	rename mothbrth parbrth 
	rename mabi parabi 
	rename vabi par2abi
	lab var parbrth "Year of birth anchor parent"
	lab var par2brth "Year of birth spouse of anchor parent"
	lab var parabi "Education anchor parent"
	lab var par2abi "Education spouse of anchor parent"
	
	tempfile mothers
	save `mothers'
restore


/*----------------------------------------------------
 
 Anchor sample for fathers

 ----------------------------------------------------*/

preserve 
	// keep only mothers born in Germany during 1930-45
	keep if fathGerm == 1

	// keep only a certain cohort range of mothers
	keep if inrange(fathbrth, 1930, 1950)

	// drop some few cases with missing information on education
	drop if mi(vabi)
	
	rename vabi fabi 
	
	// there should be no missing values left over
	misstable sum fathbrth fabi cabi brth sibl part bornde female mz* sw data age mabi

	keep fathbrth mothbrth fabi cabi brth sibl part bornde female mz* sw data age mabi

	gen anchor = 1 // fathers
	lab val anchor anchor 
	lab var anchor "Anchor sample"
	
	// normalize weights by survey 
	by data, sort: egen msw = mean(sw)
	by data, sort: gen swn = sw/msw
	// replace the sw with normalized weight
	replace sw = swn
	tabstat sw, by(data)
	drop msw swn
	
	// childlessness
	rename mz z
	rename mztrend ztrend

	// order 
	order anchor fathbrth mothbrth fabi mabi cabi brth sibl part bornde female z ztrend sw data age 
	rename mothbrth par2brth
	rename fathbrth parbrth 
	rename fabi parabi 
	rename mabi par2abi 
	lab var parbrth "Year of birth anchor parent"
	lab var par2brth "Year of birth spouse of anchor parent"
	lab var parabi "Education anchor parent"
	lab var par2abi "Education spouse of anchor parent"
	tempfile fathers
	save `fathers'
restore



/*----------------------------------------------------
 
 Combine anchor samples and calculate weights

 ----------------------------------------------------*/

use `mothers', clear
append using `fathers' 

// gen number of children from the parent's perspective 
gen F = sibl+1 
lab var F "Fertility (number of children)"

// create the family size weight
gen fsw = 1/F
lab var fsw "Family size weight"

// create a weight adjusting for over-representation of the non-childless
gen cw = 1/(1-z)
lab var cw "Having a child weight"

// indicator for cohort fertility 
gen cfr = (1-z)*F

// Cohort indicator
recode parbrth (1930/1935=1 "30/35") ///
			   (1936/1940=2 "36/40") ///
			   (1941/1945=3 "41/45") ///
			   (1946/1950=4 "46/50") ///
			   , gen(coh)

			   
			   
/*---------------------------------------------------------------------------
	
 Table 2 (Offspring samples by gender of parent, part of Germany, and parent birth cohort)
	
---------------------------------------------------------------------------*/

* 
* table anchor coh part , co(count F)

egen group = group(part anchor coh), label

log using "${logDir}/Table_2-Offspring-samples.smcl", replace

* Case numbers N
tabstat  brth [aw=sw], by(group) stats(N) f(%9.1g) varwidth(20) labelwidth(20)

* Columns for year of birth
tabstat brth [aw=sw], by(group) stats(mean sd min p5 p95 max) f(%9.1g) varwidth(20) labelwidth(20)

* Column higher educated 
tabstat cabi  [aw=sw], by(group) stats(mean) f(%9.1g) varwidth(20) labelwidth(20)

* Column siblings
tabstat  sibl [aw=sw], by(group) stats(mean sd) f(%9.1g) varwidth(20) labelwidth(20)

log close 

/*---------------------------------------------------------------------------

 Figure 2 Educational attainment in G1 and G2

 ---------------------------------------------------------------------------*/

graph bar (mean) parabi  [aw=sw*fsw*cw], over(coh, relabel(1 "1930-35" 2 "1936-40" 3 "1941-45" 4 "1946-50")) by(part anchor, colfirst note("") title("Birth cohorts")) ///
				scheme(lean1) ylabel(0(.1).5, grid)  ///
				 ytitle("Fraction high educated") name(g1, replace)

graph bar (mean) cabi  [aw=sw], over(coh, relabel(1 "1930-35" 2 "1936-40" 3 "1941-45" 4 "1946-50")) by(part anchor, colfirst note("") title("Children of birth cohorts")) ///
				scheme(lean1) ylabel(0(.1).5, grid)  ///
				 ytitle("Fraction high educated") name(g2, replace)
				 
graph combine g1 g2, scheme(lean1) row(2) ycommon iscale(*.8) xsize(10) ysize(14.1)

graph play grec/adjust-figure-two-generation-education.grec
graph export "${logDir}/Figure_2-education-in-two-generations.pdf", replace	

/*
/* Alternative Figure design to fit the Demography layout */
// https://www.springer.com/journal/13524/submission-guidelines#Instructions%20for%20Authors_Artwork%20and%20Illustrations%20Guidelines 

* 1 inch = 25.4 mm 
* Small journals: 119 mm wide (4.685 inch), 195 mm (7.677 inch) high (max)

graph combine g1 g2, row(2) ///
						  graphregion(margin(0 0 0 0)) ///
						  imargin(1 1 1 1) ///
						  scheme(lean1) ysize(7.677) xsize(4.685) name(Figure_2, replace)
						  
graph play grec/adjust-figure-DEMOGRAPHY-adjust-Figure-2.grec

graph export "${logDir}/Figure-2-WIDE.pdf", replace
graph export "${logDir}/Figure-2-WIDE.svg", replace
graph export "${logDir}/Figure-2-WIDE.eps", replace
*/
 
/*---------------------------------------------------------------------------
// Descriptive statistics offspring parents, parents, and cohort 1930-1945
---------------------------------------------------------------------------*/

// Descriptive statistics on the samples

// no row totals as respondents are included twice
* Offspring perspective
table anchor part [aw=sw], co(mean parabi mean parbrth mean F) f(%9.2g)  col
* Parents
table anchor part [aw=sw*fsw], co(mean parabi mean parbrth mean F) f(%9.2g)  col
* Cohort
table anchor part [aw=sw*fsw*cw], co(mean parabi mean parbrth mean cfr) f(%9.2g)  col

// who are the fathers and mothers marrying?
tabstat parbrth par2brth if anchor==1 [aw=sw*fsw], stats(mean p50 sd min max)
tabstat parbrth par2brth if anchor==2 [aw=sw*fsw], stats(mean p50 sd min max)



// case numbers 
tab anchor part

// Mother's & Father's age at birth 
gen parage = brth-parbrth

table anchor parabi part  [aw=sw*fsw], co(mean parage mean F) f(%9.2g)  col
// offsprings average birth
table anchor parabi part  [aw=sw], co(mean brth sd brth min brth max brth) f(%9.2g)  col
// offsprings siblings
table anchor parabi part  [aw=sw], co(mean sibl) f(%9.2g)  col

// Age at childbirth - parents (retrospectively)
fre parage if anchor == 1 [aw=sw] // fathers
fre parage if anchor == 2 [aw=sw] // Mothers


/*---------------------------------------------------------------------------

 Figure A3 (comparison of fertility rates with official rates)

---------------------------------------------------------------------------*/

// Compare calculated CFR per year with official historical data for women
// Statistisches Bundesamt	
// https://www.destatis.de/DE/ZahlenFakten/GesellschaftStaat/Bevoelkerung/Geburten/Tabellen/EndgueltigeKinderzahl.html
preserve 
	clear
	input parbrth DE_CFR WEST_CFR EAST_CFR
	1930	2.121	2.141	.
	1931	2.164	2.163	.
	1932	2.201	2.2		.
	1933	2.224	2.225	.	
	1934	2.221	2.24	.
	1935	2.167	2.173	.
	1936	2.132	2.135	.
	1937	2.108	2.108	2.082
	1938	2.069	2.07	2.044
	1939	2.026	2.025	2.016
	1940	1.977	1.971	1.983
	1941	1.917	1.903	1.952
	1942	1.864	1.85	1.9
	1943	1.83	1.81	1.891
	1944	1.801	1.778	1.874
	1945	1.795	1.775	1.862
	1946	1.795	1.780	1.866
	1947	1.770	1.752	1.834
	1948	1.750	1.729	1.826
	1949	1.735	1.715	1.802
	1950	1.724	1.701	1.790
	end 
	tempfile official 
	save `official'
restore
preserve 
	tabstat cfr if anchor==2 [aw=sw*fsw*cw], by(parbrth)
	collapse (mean) cfr [aw=sw*fsw*cw], by(anchor parbrth) 
	merge n:1 parbrth using `official', nogen
	sum DE_CFR if anchor==2 // 1.97, official data
	sum cfr if anchor == 2	// 1.91, our estimates (pretty close)

	li, noobs clean
	
	twoway (scatter cfr parbrth if anchor==2, c(l)) (scatter cfr parbrth if anchor==1, c(l) lpat(shortdash))  (scatter DE_CFR parbrth if anchor==2, c(l)) /// (scatter cfr parbrth if anchor==1, c(l)) 
		   , ylabel(1.5(.1)2.5, angle(360) format(%9.1f)) ysize(10) xlabel(1930(5)1950) xmtick(1930(1)1950) xsize(10) scheme(s1color) ///
		   name(cfr, replace) ytitle(Cohort fertility rate) xtitle(Year of birth) legend(lab(1 "Women (adjusted sample)") lab(2 "Men (adjusted sample)") lab(3 "Women (official data)") order(3 1 2) ring(0) pos(2) size(small) col(1) region(lcolor(none)))
	graph export "${logDir}/Figure_A3.pdf", replace	   
restore 

* Levels of childlessness men and women 
preserve 
collapse (mean) z [aw=sw*fsw*cw], by(anchor parbrth) 
tabstat z , by(anchor)
restore


/*---------------------------------------------------------------------------
Figure A2. Male and female target cohorts and their offspring after adjustment.
---------------------------------------------------------------------------*/

// Supplementary Figure  - Men and Women born 1930-1950 and their offspring (adjustment)

* WOMEN 
* mothers' offspring
preserve
	keep if anchor == 2 // select mothers' offspring
	gen n = sw
	collapse (sum) n, by(brth)
	tempfile mothers_offspring
	save `mothers_offspring'
restore
* mothers 
preserve
	keep if anchor == 2 // select mothers' offspring
	gen n = sw
	gen n_sibw = sw*fsw	// considering the family size weights is essential!
	collapse (sum) n n_sibw , by(parbrth)
	rename parbrth brth
	gen mothers = 1
	tempfile mothers
	save `mothers'
restore

* a dataset containing childlessness rates of women per year of birth
preserve
	keep if anchor == 2 // select mothers' offspring
	
	collapse (mean) z [aw=sw*fsw*cw], by(parbrth)
	rename parbrth brth
	gen mothers = 1
	rename z zero
	tempfile wzero
	save `wzero'
restore

// calculate some cohort based indicators 
* cohort fertility rate 
sum cfr [aw=sw*fsw*cw] if anchor==2
local cfr = round(r(mean),.01)
* number of children per mother
sum F [aw=sw*fsw] if anchor==2
local fert = round(r(mean),.01)
* childlessness
sum z [aw=sw*fsw*cw] if anchor==2
local zero = round(r(mean)*100,.01)

preserve
	use `mothers_offspring', clear
	append using `mothers'
	merge n:1 brth using `wzero', assert(matched master) nogen
	
	/*
	egen N_children = total(n) if mothers==. 
	egen N_mothers = total(n_sibw) if mothers==1
	sum N_children 
	local c = r(mean)
	sum N_mothers 
	local m = r(mean)
	*/
	gen nfull = n_sibw/(1-zero) if mothers==1
	gen nfullbrth = brth + .25
	replace brth = brth-.25 if mothers==1

	// here the mother generation appears to be much more plausible
	twoway (bar n_sibw brth if mothers==1, barwidth(.5) color(cranberry)) (bar nfull nfullbrth if mothers==1, barwidth(.5) color(gs8)) (bar n brth if mothers==., barwidth(.5) color(green)) , ///
			scheme(s1color)  xlabel(1930(5)1990) title("", size(med)) name(women_mothers_offspring, replace) ///
			legend(lab(1 "Mothers") lab(2 "Women") lab(3 "Offspring of Mothers") order(2 1 3) ring(0) pos(2) col(1) size(vsmall) region(style(none)) textfirst symysize(*.5)) /// 
			text(600 1950 "Cohort fertility:" "`cfr'", size(small)) ///
			text(500 1950 "Children per mother:" "`fert'", size(small)) ///
			text(500 1935 "Childless:" "`zero'%", size(small)) ///
			xtitle(Year) ytitle("Population proportion adjusted sample size") // ylabel(, grid glcolor(gs14) glstyle(shortdash))
			
	* graph export "${logDir}/Figure_5-women_mothers_offspring.pdf", replace

restore

* MEN 
* Fathers' offspring
preserve
	keep if anchor == 1 // select fathers' offspring
	gen n = sw
	collapse (sum) n, by(brth)
	li
	tempfile fathers_offspring
	save `fathers_offspring'
restore
* fathers 
preserve
	keep if anchor == 1 // select fathers' offspring
	gen n = sw
	gen n_sibw = sw*fsw	// considering the family size weights is essential!
	collapse (sum) n n_sibw , by(parbrth)
	rename parbrth brth
	gen fathers = 1
	tempfile fathers
	save `fathers'
restore

* a dataset containing childlessness rates of men per year of birth
preserve
	keep if anchor == 1 // select mothers' offspring
	
	collapse (mean) z [aw=sw*fsw*cw], by(parbrth)
	rename parbrth brth
	gen fathers = 1
	rename z zero
	tempfile mzero
	save `mzero'
restore

// calculate some cohort based indicators 
* cohort fertility rate 
sum cfr [aw=sw*fsw*cw] if anchor==1
local cfr = round(r(mean),.01)
* number of children per father
sum F [aw=sw*fsw] if anchor==1
local fert = round(r(mean),.01)
* childlessness
sum z [aw=sw*fsw*cw] if anchor==1
local zero = round(r(mean)*100,.01)

preserve
	use `fathers_offspring', clear
	append using `fathers'
	merge n:1 brth using `mzero', assert(matched master) nogen
	
	/*
	egen N_children = total(n) if mothers==. 
	egen N_mothers = total(n_sibw) if mothers==1
	sum N_children 
	local c = r(mean)
	sum N_mothers 
	local m = r(mean)
	*/
	gen nfull = n_sibw/(1-zero) if fathers==1
	gen nfullbrth = brth + .25
	replace brth = brth-.25 if fathers==1
	li if brth <1951
	// here the mother generation appears to be much more plausible
	twoway	 (bar n_sibw brth if fathers==1, barwidth(.5) color(blue)) ///
			 (bar nfull nfullbrth if fathers==1, barwidth(.5) color(gs8)) ///
			 (bar n brth if fathers==. , barwidth(.5) color(green)) , ///
			scheme(s1color)  xlabel(1930(5)1990) title("", size(med)) name(men_fathers_offspring, replace) ///
			legend(lab(1 "Fathers") lab(2 "Men") lab(3 "Offspring of Fathers") order(2 1 3) ring(0) pos(2) col(1) size(vsmall) region(style(none)) textfirst symysize(*.5)) /// 
			text(600 1950 "Cohort fertility:" "`cfr'", size(small)) ///
			text(500 1950 "Children per father:" "`fert'", size(small)) ///
			text(500 1935 "Childless:" "`zero'%", size(small)) ///
			xtitle(Year) ytitle("Population proportion adjusted sample size") /// ylabel(, grid glcolor(gs14) glstyle(shortdash))
			
	* graph export "${logDir}/Figure_5-men_fathers_offspring.png", replace

restore

graph combine women_mothers_offspring men_fathers_offspring, row(2) xsize(9) ysize(15) scheme(lean1)
graph export "${logDir}/Figure_A2.pdf", replace




// Additional figure (not shown in the material) 
// Educational stratification in two generations
preserve
	collapse (mean) parabi [aw=sw*fsw*cw], by(anchor parbrth part)
	gen parents = 0
	tempfile individuals
	save `individuals'
restore
preserve
	recode brth (1944/1950=1950 "1944/1950") (1980/1988=1980 "1980/1988"), gen(b)
	collapse (mean) cabi [aw=sw], by(anchor b part)
	tempfile offspring
	gen offspring = 1
	save `offspring'
restore
preserve
	collapse (mean) parabi [aw=sw*fsw], by(anchor parbrth part)
	gen parents=1
	tempfile parents
	save `parents'
restore
preserve
	use `individuals', clear
	append using `parents' 
	append using `offspring' 
	twoway (lowess parabi parbrth  if part==1 & parents==0 & anchor==2, c(l) sort lcol(cranberry) ) ///
		   (lowess parabi parbrth  if part==1 & parents==1 & anchor==2, c(l) sort lcol(cranberry) lpat(shortdash)) ///
		   (lowess parabi parbrth  if part==1 & parents==0 & anchor==1, c(l) sort lcol(blue) ) ///
		   (lowess parabi parbrth  if part==1 & parents==1 & anchor==1, c(l) sort lcol(blue) lpat(shortdash)) ///
		   , name(east, replace) scheme(s1color) xtitle(year) xlabel(1930(5)1945, angle(45)) xmtick(1930(1)1945) ///
		     legend(lab(1 "Women") lab(2 "Mothers") lab(3 "Men") lab(4 "Fathers") size(vsmall) row(4) ring(0) pos(11)) ///
			 ytitle("Fraction") ylabel(0(.10).8, grid angle(horizontal)) title("G1 – East Germany", size(med)) xtitle("Year of birth") 
	twoway (lowess parabi parbrth  if part==2 & parents==0 & anchor==2, c(l) sort lcol(cranberry) ) ///
		   (lowess parabi parbrth  if part==2 & parents==1 & anchor==2, c(l) sort lcol(cranberry) lpat(shortdash)) ///
		   (lowess parabi parbrth  if part==2 & parents==0 & anchor==1, c(l) sort lcol(blue) ) ///
		   (lowess parabi parbrth  if part==2 & parents==1 & anchor==1, c(l) sort lcol(blue) lpat(shortdash)) ///
		   , name(west, replace) scheme(s1color) xtitle(year) xlabel(1930(5)1945, angle(45)) xmtick(1930(1)1945) ///
		     legend(lab(1 "Women") lab(2 "Mothers") lab(3 "Men") lab(4 "Fathers") size(vsmall) row(4) ring(0) pos(11)) ///
			 ytitle("Fraction") ylabel(0(.10).8, grid angle(horizontal)) title("G1 – West Germany", size(med)) xtitle("Year of birth") 
	
	twoway (lowess cabi b  if part==2 & offspring==1 & anchor==2 , c(l) sort lcol(cranberry) ) ///
		   (lowess cabi b  if part==2 & offspring==1 & anchor==1 , c(l) sort lcol(blue) ) ///
		   , name(west_offspring, replace) scheme(s1color) xtitle(year) xlabel(1950(5)1980, value angle(45)  labsize(small)) xmtick(1950(1)1980) ///
		     legend(lab(1 "Women's offspring") lab(2 "Men's offspring") size(vsmall) row(4) ring(0) pos(11)) ///
			 ytitle("Fraction") ylabel(, grid angle(horizontal)) title("G2 – West Germany", size(med)) xtitle("Year of birth") ylabel(0(.1).8, grid  angle(horizontal))
	twoway (lowess cabi b  if part==1 & offspring==1 & anchor==2 , c(l) sort lcol(cranberry) ) ///
		   (lowess cabi b  if part==1 & offspring==1 & anchor==1 , c(l) sort lcol(blue) ) ///
		   , name(east_offspring, replace) scheme(s1color) xtitle(year) xlabel(1950(5)1980, value angle(45) labsize(small)) xmtick(1950(1)1980) ///
		     legend(lab(1 "Women's offspring") lab(2 "Men's offspring") size(vsmall) row(4) ring(0) pos(11)) ///
			 ytitle("Fraction") ylabel(, grid angle(horizontal)) title("G2 – East Germany", size(med)) xtitle("Year of birth") ylabel(0(.1).8, grid  angle(horizontal))
	
	graph combine west east west_offspring east_offspring, rows(2) graphregion(color(white))
	
restore


// Finally, some descriptive numbers on offspring by education 
// West Germany 
* Women 
tabstat cabi brth female F if part == 2 & anchor == 2 [aw=sw], by(parabi) f(%9.2g) // offspring born later for those with abitur
* Men
tabstat cabi brth female F if part == 2 & anchor == 1 [aw=sw], by(parabi) f(%9.2g) // offspring born later for those with abitur
// East Germany 
* Women 
tabstat cabi brth female F if part == 1 & anchor == 2 [aw=sw], by(parabi) f(%9.2g) // offspring born later for those with abitur
* Men
tabstat cabi brth female F if part == 1 & anchor == 1 [aw=sw], by(parabi) f(%9.2g) // offspring born later for those with abitur



 
// Save data
save "${tempDir}/04_parent_samples", replace 
