/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Skopek, Jan and Leopold, Thomas (2020). Educational Reproduction in Germany: 
  A Prospective Study Based on Retrospective Data. In: Demography.
  
  10_educational_reproduction.do	
	
  Note: The do-files defines at the beginning the program "prospective_srr" which
	    does all the calculation of prosective parameters.
		
	
  Part A) Rates of educational reproduction + decomposition of joint effects 
		  into fertility and mobility components.
  	
	
	
	Estimates models (fertility and mobility) and parameters of educational reproduction.

	Outputs: 
	
	- Figure 1 (Cohort fertility rate total (CFR) and conditional on parenthood (PFR))
	
	- Figure 3 (Educational mobility)
	
	- Figure 4 (rates of educational reproduction)
	
	- Figure 5 (Joint effect on educational reproduction)

	- Table 3 (Fertility behavior by gender, part of Germany, education, and cohort)
	
	- APPENDIX: Table B2 (Educational mobility: Probability of attaining higher education 
			    by family characteristics for offspring of fathers)
	
	- APPENDIX: Table B3 (Educational mobility: Probability of attaining higher education 
			    by family characteristics for offspring of mothers)
	
	- APPENDIX: Table B4 (Rates of educational reproduction)
	
	- APPENDIX: Table B5 (Joint effect, mobility effect, and fertility effect in producing 
				high educated offspring)
				
	- APPENDIX: Table B6 (Joint effect, mobility effect, and fertility effect in producing 
				low educated offspring)
	
	Part B) Population renewal models
	
	Links educational reproduction rates with population parameters to analyse 
	consequences of differential fertility for inequality in the offspring generation.
	
	Outputs:
	
	- Figure 6 (Scenario analyses)
	
	- APPENDIX: Table B7 (Projection values for scenario analysis)
	
	- APPENDIX: Table B8 (Projection values for scenario analysis - Part II)

*/

////////////////////////////////////////////////////////////////////////////////
// 
// Program for calculating social reproduction rates (srr)
// 
////////////////////////////////////////////////////////////////////////////////
capt program drop prospective_srr
program define prospective_srr, eclass
	syntax [if] // the if statement is very important 
	// preserve
	quiet {
		tempvar pr prcf s scf c
		
		logit cabi i.parabi c.F c.data [pw=sw] `if' // 
		est store ret 
		
		local N = `e(N)'
		
		// setting data to .5 (average dataset) 
		rename data _data 
		gen data = .5 `if'

		// predict child's probability of having abi=1
		predict `pr' `if'
		
		// 
		tempvar pr0 pr0cf s0 s0cf // child's probability of having not abi=1
		gen `pr0' = 1-`pr' `if'
		
		preserve 
			keep `if'
			collapse `pr' [aw=sw] , by(parabi)
			drop parabi
			mkmat `pr' , mat(p)
		restore 
		
		gen `c' = (1-z)	// probability of having children

		// children?
		preserve 
			keep `if'
			collapse `c' [aw=sw*fsw*cw] , by(parabi)
			drop parabi
			mkmat `c' , mat(child)
		restore 
		
		// f | f > 0
		preserve 
			keep `if'
			collapse F [aw=sw*fsw] , by(parabi)
			drop parabi
			mkmat F , mat(f)
		restore 

		mat cfr = (child[1,1]*f[1,1]) \ (child[2,1]*f[2,1])
		
		// predict counterfactuals probability 
		rename parabi _parabi 
		gen parabi = _parabi == 0 `if'
		predict `prcf' `if'
		
		// not abi
		gen `pr0cf' = 1-`prcf' `if'
		
		drop parabi 
		rename _parabi parabi

		gen `s' = F*`pr'  `if'
		gen `scf' = F*`prcf'  `if'

		// not abi
		gen `s0' = F*`pr0'  `if'
		gen `s0cf' = F*`pr0cf'  `if'
		
		preserve 
			keep `if'
			collapse `s' `scf' [aw=sw*fsw*cw] , by(parabi)
			// li, noobs clean
			mkmat `s' `scf', mat(c) rownames(parabi)
			/* noisily: mat li c */
		restore
		
		// matrix r: Contains reproduction rates for outcome "high" educated children. 
		/*
			Matrix structure
				 1		 2
			1	(a)		(b)		-> low educated women/men
			2	(c)		(d)		-> high educated women/men
				
				 ^   	 ^
				Obs		 CF		-> CF = counterfactual rate under fertility distribution of the other group 
				
			r[1,1]	=> Obs: production rate of high educated children for low educated women/men
			r[1,2]	=> CF:  production rate of high educated children for low educated women/men if they had the fertility of high educated women/men
			r[2,1]	=> Obs: production rate of high educated children for high educated women/men
			r[2,2]	=> CF:  production rate of high educated children for high educated women/men if they had the fertility of low educated women/men
		*/
		mat r = (c[1,1]*child[1,1], c[1,2]*child[1,1]) \ (c[2,1]*child[2,1], c[2,2]*child[2,1])
		
		/* noisily: mat li r */
		
		// no abi
		preserve 
			keep `if'
			collapse `s0' `s0cf' [aw=sw*fsw*cw] , by(parabi)
			// li, noobs clean
			mkmat `s0' `s0cf', mat(c0) rownames(parabi)
		// mat li c
		restore
		
		// matrix r0: Contains reproduction rates for outcome "low" educated children. 
		/*
			(structure analogous to r) 
			
			Matrix structure
				 1		 2
			1	(a)		(b)		-> low educated women/men
			2	(c)		(d)		-> high educated women/men
				
				 ^   	 ^
				Obs		 CF		-> CF = counterfactual rate under fertility distribution of the other group 
				
			r0[1,1]	=> Obs: production rate of low educated children for low educated women/men
			r0[1,2]	=> CF:  production rate of low educated children for low educated women/men if they had the fertility of high educated women/men
			r0[2,1]	=> Obs: production rate of low educated children for high educated women/men
			r0[2,2]	=> CF:  production rate of low educated children for high educated women/men if they had the fertility of low educated women/men
		*/
		mat r0 = (c0[1,1]*child[1,1], c0[1,2]*child[1,1]) \ (c0[2,1]*child[2,1], c0[2,2]*child[2,1])
	
		/* noisily: mat li r0 */
		
		// Social (educational) reproduction rates for outcome 'high educated children'
		* save values in locals
		local sr00 = r[1,1]	// Obs: # of high educated children for low educated persons
		local sr01 = r[1,2]	// CF:  # of high educated children for low educated persons if they had fertility of high educated persons
		local sr10 = r[2,2] // CF:  # of high educated children for high educated persons if they had fertility of low educated persons
		local sr11 = r[2,1] // Obs: # of high educated children for high educated persons

		// Social (educational) reproduction rates for outcome 'low educated children'
		* save values in locals
		local sr000 = r0[1,1]	// Obs:	(low educated)
		local sr001 = r0[1,2]	// CF:	(low educated but fertility of high)
		local sr010 = r0[2,2]	// CF:	(high educated but fertility of low)
		local sr011 = r0[2,1]	// Obs: (high educated)
		
		// (A) Total effect, fertility and mobility components for outcome 'high educated children' 
		
		* total effect 
		local te =  r[2,1] - r[1,1]

		* fertility part 
		local fe =  0.5*(r[2,1] - r[1,2] + r[2,2] - r[1,1])

		* IEO part 
		local ieo =  0.5*(r[2,1] + r[1,2] - r[2,2]  - r[1,1])

		* fertility %
		local fe_rel = 0.5*(r[2,1] - r[1,2] + r[2,2] - r[1,1]) / (r[2,1] - r[1,1]) 

		// (B) Total effect, fertility and mobility components for outcome 'low educated children' 
		
		* total effect 
		local te0 =  r0[2,1] - r0[1,1]

		* fertility part 
		local fe0 =  0.5*(r0[2,1] - r0[1,2] + r0[2,2] - r0[1,1])

		* IEO part 
		local ieo0 =  0.5*(r0[2,1] + r0[1,2] - r0[2,2]  - r0[1,1])

		* fertility %
		local fe_rel0 = 0.5*(r0[2,1] - r0[1,2] + r0[2,2] - r0[1,1]) / (r0[2,1] - r0[1,1]) 

		
		drop data 
		rename _data data
	}
	
	// Song & Mare 2015
	ereturn clear 
	
	// Transmission 
	ereturn scalar rp0 = p[1,1] // retrospective probability cabi=1 for parabi = 1 (at data=.5)
	ereturn scalar rp1 = p[2,1] // retrospective probability cabi=1 for parabi = 0 (at data=.5)
	ereturn scalar lnror = ln((p[2,1]/(1-p[2,1])) / (p[1,1]/(1-p[1,1])) ) // retrospective OR (at data=.5)
	
	// Fertility
	ereturn scalar z0 = 1-child[1,1]
	ereturn scalar z1 = 1-child[2,1]
	ereturn scalar f0 = f[1,1]
	ereturn scalar f1 = f[2,1]
	ereturn scalar cfr0 = cfr[1,1]
	ereturn scalar cfr1 = cfr[2,1]
	
	// Social reproduction: Outcome 'high educated children' (abitur)
	* Observed and counterfactual rates (sr-ij: i = educational group i, j = fertility of educational group j; 0=low, 1=high)
	ereturn scalar sr00 = `sr00'	// Obs: low educated
	ereturn scalar sr01 = `sr01'	// CF:	low educated but fertility of high educated
	ereturn scalar sr10 = `sr10'	// CF:  high educated but fertility of low educated	
	ereturn scalar sr11 = `sr11'	// Obs: high educated
	
	* Joint effect and components
	ereturn scalar te = `te'
	ereturn scalar fe = `fe'
	ereturn scalar ieo = `ieo'
	ereturn scalar fe_rel = `fe_rel'
	
	
	// Social reproduction: Outcome 'low educated children' (no abitur)
	* Observed and counterfactual rates (sr0-ij: i = educational group i, j = fertility of educational group j; 0=low, 1=high)
	ereturn scalar sr000 = `sr000'
	ereturn scalar sr001 = `sr001'
	ereturn scalar sr010 = `sr010'
	ereturn scalar sr011 = `sr011'
	
	* Joint effect and components
	ereturn scalar te0 = `te0'
	ereturn scalar fe0 = `fe0'
	ereturn scalar ieo0 = `ieo0'
	ereturn scalar fe_rel0 = `fe_rel0'
	
	
	ereturn scalar N = `N' // case numbers
	// restore
end 



use "${tempDir}/04_parent_samples", clear

/*------------------------------------------------------------------------------

  Part A) Rates of educational reproduction + decomposition of joint effects 
		  into fertility and mobility components.
		  
------------------------------------------------------------------------------*/
		  
/*----------------------------------------------------

	Table B2. Educational mobility: 
	Probability of attaining higher education by family characteristics 
	for offspring of fathers.
	
	+ 
	
	Table B3. Educational mobility: 
	Probability of attaining higher education by family characteristics 
	for offspring of mothers.
	
----------------------------------------------------*/

// Underlying models
* IEO
foreach c of numlist 1/4 {
	logit cabi i.parabi c.F c.data [pw=sw] if coh==`c' & anchor == 1 & part == 1
	est store EM`c' 
	margins, dydx(parabi F ) at(data=.5) post
	est store AME_EM`c'

	logit cabi i.parabi c.F c.data [pw=sw] if coh==`c' & anchor == 1 & part == 2
	est store WM`c'
	margins, dydx(parabi F ) at(data=.5) post
	est store AME_WM`c'
	
	logit cabi i.parabi c.F c.data [pw=sw] if coh==`c' & anchor == 2 & part == 1
	est store EW`c' 
	margins, dydx(parabi F ) at(data=.5) post
	est store AME_EW`c'
	
	logit cabi i.parabi c.F c.data [pw=sw] if coh==`c' & anchor == 2 & part == 2
	est store WW`c'
	margins, dydx(parabi F ) at(data=.5) post
	est store AME_WW`c'
}

log using "${logDir}/Table_B2-Educational-mobility-offspring-fathers.smcl", replace

// TABLE B2 (offspring of fathers)
* log-odds 
est table EM1 EM2 EM3 EM4, b(%9.3f) star stats(N r2_p)
est table WM1 WM2 WM3 WM4, b(%9.3f) star stats(N r2_p)
* AMEs
est table AME_EM1 AME_EM2 AME_EM3 AME_EM4, b(%9.3f) star stats(N r2_p)
est table AME_WM1 AME_WM2 AME_WM3 AME_WM4, b(%9.3f) star stats(N r2_p)

log close 

log using "${logDir}/Table_B3-Educational-mobility-offspring-mothers.smcl", replace

// TABLE B3 (offspring of mothers)
* log-odds
est table EW1 EW2 EW3 EW4, b(%9.3f) star stats(N r2_p)
est table WW1 WW2 WW3 WW4, b(%9.3f) star stats(N r2_p)
* AMEs
est table AME_EW1 AME_EW2 AME_EW3 AME_EW4, b(%9.3f) star stats(N r2_p)
est table AME_WW1 AME_WW2 AME_WW3 AME_WW4, b(%9.3f) star stats(N r2_p)

log close 

/*----------------------------------------------------

Figure 3 (Educational mobility)

----------------------------------------------------*/

local zeroline "gs3" // "cranberry" 
coefplot AME_EM1, bylabel("1930-35") || AME_EM2, bylabel("1936-40") || AME_EM3, bylabel("1941-45") || AME_EM4 , bylabel("1946-50") ||,  ///
		 bycoefs xline(0, lcol(`zeroline')) scheme(lean1) ///
		 coeflabels(1.parabi = "Parent's education: high vs. low" F = "Family size") ///
		 byopts(title("East – Offspring of fathers")) xlabel(-.2(.2).6) xmtick(-.2(.1).7) ///
		 name(EM, replace) xtitle("AME") msymbol(O) ciopts(lwidth(med))
coefplot AME_WM1, bylabel("1930-35") || AME_WM2, bylabel("1936-40") || AME_WM3, bylabel("1941-45") || AME_WM4 , bylabel("1946-50") ||,  ///
		 bycoefs xline(0, lcol(`zeroline')) scheme(lean1) ///
		 coeflabels(1.parabi = "Parent's education: high vs. low" F = "Family size") ///
		 byopts(title("West – Offspring of fathers")) xlabel(-.2(.2).6) xmtick(-.2(.1).7) ///
		 name(WM, replace) xtitle("AME") msymbol(O) ciopts(lwidth(med))
coefplot AME_EW1, bylabel("1930-35") || AME_EW2, bylabel("1936-40") || AME_EW3, bylabel("1941-45") || AME_EW4 , bylabel("1946-50") ||,  ///
		 bycoefs xline(0, lcol(`zeroline')) scheme(lean1) ///
		 coeflabels(1.parabi = "Parent's education: high vs. low" F = "Family size") ///
		 byopts(title("East – Offspring of mothers")) xlabel(-.2(.2).6) xmtick(-.2(.1).7) ///
		 name(EW, replace) xtitle("AME") msymbol(O) ciopts(lwidth(med))
coefplot AME_WW1, bylabel("1930-35") || AME_WW2, bylabel("1936-40") || AME_WW3, bylabel("1941-45") || AME_WW4 , bylabel("1946-50") ||,  ///
		 bycoefs xline(0, lcol(`zeroline')) scheme(lean1) ///
		 coeflabels(1.parabi = "Parent's education: high vs. low" F = "Family size") ///
		 byopts(title("West – Offspring of mothers")) xlabel(-.2(.2).6) xmtick(-.2(.1).7) ///
		 name(WW, replace) xtitle("AME") msymbol(O) ciopts(lwidth(med))

graph combine EM WM EW WW, rows(2) iscale(*.8) xsize(15) ysize(10) graphregion(margin(0 0 0 0) col(white)) scheme(lean1) imargin(0 0 0 0)
		 
graph export "${logDir}/Figure_3-educational-mobility.pdf", replace	

/*
/* Alternative Figure design to fit the Demography layout */
// https://www.springer.com/journal/13524/submission-guidelines#Instructions%20for%20Authors_Artwork%20and%20Illustrations%20Guidelines 

* 1 inch = 25.4 mm 
* Small journals: 119 mm wide (4.685 inch), 195 mm (7.677 inch) high (max)

graph combine EM WM EW WW, cols(2) ///
						  graphregion(margin(0 0 0 0)) ///
						  imargin(1 1 1 1) ///
						  scheme(lean1) ysize(4.685) xsize(7.677) name(Figure_3, replace)
						  
graph play grec/adjust-figure-DEMOGRAPHY-adjust-Figure-3.grec

graph export "${logDir}/Figure-3-WIDE.pdf", replace
graph export "${logDir}/Figure-3-WIDE.svg", replace
graph export "${logDir}/Figure-3-WIDE.eps", replace
*/


/*----------------------------------------------------

	Table 3 Fertility behavior by gender, part of 
			Germany, education, and cohort.

----------------------------------------------------*/
preserve 
	collapse (mean) F z [aw=sw*fsw], by(anchor part coh parabi)
	gen cfr = (1-z)*F
	li 
	keep anchor part coh parabi z F cfr
	order anchor part coh parabi z F cfr
	reshape wide z F cfr, i(anchor part coh) j(parabi)
	format %9.3f z*
	format %9.2f F* cfr*
	
	log using "${logDir}/Table_3-Fertility-by-gender-cohort-part.smcl", replace

	li, noobs clean 
	
	log close
restore



/*----------------------------------------------------

	Figure 1 Cohort fertility rate total (CFR) and 
			 conditional on parenthood (PFR)

----------------------------------------------------*/
preserve 
	collapse (mean) F z (sd) sdf = F sdz=z [aw=sw*fsw], by(anchor part coh parabi)
	* check uf sdz (standard deviation of childlessness) = 0 - ok!
	gen cfr = (1-z)*F
	li
	sort anchor part 
	// East- MEN 
	twoway (scatter F coh if anchor == 1 & part == 1 & parabi==0, c(l) lpat(shortdash) msymb(T) mcol(gs10) lcol(gs10)) ///
		   (scatter cfr coh if anchor == 1 & part == 1 & parabi==0, c(l) lpat(solid) msymb(T) mcol(gs10) lcol(gs10)) ///
		   (scatter F coh if anchor == 1 & part == 1 & parabi==1, c(l) lpat(shortdash) msymb(D) lcol(black)) ///
		   (scatter cfr coh if anchor == 1 & part == 1 & parabi==1, c(l) lpat(solid) msymb(D) lcol(black)) ///
		   , xlabel(1 "1930-35" 2 "1936-40" 3 "1941-45" 4 "1946-50") xtitle("") ytitle("Average number of children") ///
		     legend(lab(1 "Low educated (fathers)") lab(2 "Low educated (all men)") ///
				    lab(3 "High educated (fathers)") lab(4 "High educated (all men)") region(color(none)) row(2) pos(2) ring(0)) ///
					scheme(lean1) name(EM, replace) title("Men – East") ylabel(1.5(.25)2.5, grid) graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 	
	// West - MEN 
	twoway (scatter F coh if anchor == 1 & part == 2 & parabi==0, c(l) lpat(shortdash) msymb(T) mcol(gs10) lcol(gs10)) ///
		   (scatter cfr coh if anchor == 1 & part == 2 & parabi==0, c(l) lpat(solid) msymb(T) mcol(gs10) lcol(gs10)) ///
		   (scatter F coh if anchor == 1 & part == 2 & parabi==1, c(l) lpat(shortdash) msymb(D) lcol(black)) ///
		   (scatter cfr coh if anchor == 1 & part == 2 & parabi==1, c(l) lpat(solid) msymb(D) lcol(black)) ///
		   , xlabel(1 "1930-35" 2 "1936-40" 3 "1941-45" 4 "1946-50") xtitle("") ytitle("Average number of children") ///
		     legend(lab(1 "Low educated (fathers)") lab(2 "Low educated (all men)") ///
				    lab(3 "High educated (fathers)") lab(4 "High educated (all men)") region(color(none)) row(2) pos(2) ring(0)) ///
					scheme(lean1) name(WM, replace) title("Men – West") ylabel(1.5(.25)2.5, grid) graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 	
	// East- WOMEN 
	twoway (scatter F coh if anchor == 2 & part == 1 & parabi==0, c(l) lpat(shortdash) msymb(T) mcol(gs10) lcol(gs10)) ///
		   (scatter cfr coh if anchor == 2 & part == 1 & parabi==0, c(l) lpat(solid) msymb(T) mcol(gs10) lcol(gs10)) ///
		   (scatter F coh if anchor == 2 & part == 1 & parabi==1, c(l) lpat(shortdash) msymb(D) lcol(black)) ///
		   (scatter cfr coh if anchor == 2 & part == 1 & parabi==1, c(l) lpat(solid) msymb(D) lcol(black)) ///
		   , xlabel(1 "1930-35" 2 "1936-40" 3 "1941-45" 4 "1946-50") xtitle("") ytitle("Average number of children") ///
		     legend(lab(1 "Low educated (mothers)") lab(2 "Low educated (all women)") ///
				    lab(3 "High educated (mothers)") lab(4 "High educated (all women)") region(color(none)) row(2) pos(2) ring(0)) ///
					scheme(lean1) name(EW, replace) title("Women – East") ylabel(1.5(.25)2.5, grid) graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 	
	// West - WOMEN 
	twoway (scatter F coh if anchor == 2 & part == 2 & parabi==0, c(l) lpat(shortdash) msymb(T) mcol(gs10) lcol(gs10)) ///
		   (scatter cfr coh if anchor == 2 & part == 2 & parabi==0, c(l) lpat(solid) msymb(T) mcol(gs10) lcol(gs10)) ///
		   (scatter F coh if anchor == 2 & part == 2 & parabi==1, c(l) lpat(shortdash) msymb(D) lcol(black)) ///
		   (scatter cfr coh if anchor == 2 & part == 2 & parabi==1, c(l) lpat(solid) msymb(D) lcol(black)) ///
		   , xlabel(1 "1930-35" 2 "1936-40" 3 "1941-45" 4 "1946-50") xtitle("") ytitle("Average number of children") ///
		     legend(lab(1 "Low educated (mothers)") lab(2 "Low educated (all women)") ///
				    lab(3 "High educated (mothers)") lab(4 "High educated (all women)") region(color(none)) row(2) pos(2) ring(0)) ///
					scheme(lean1) name(WW, replace) title("Women – West") ylabel(1.5(.25)2.5, grid)	graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 	
	
graph combine EM WM EW WW, rows(2) iscale(*.6) ycommon xsize(15) ysize(10) graphregion(margin(1 1 1 1) col(white)) scheme(lean1) imargin(2 2 2 2)
graph export "${logDir}/Figure_1-CFR-PFR.pdf", replace

/*
/* Alternative Figure design to fit the Demography layout */
// https://www.springer.com/journal/13524/submission-guidelines#Instructions%20for%20Authors_Artwork%20and%20Illustrations%20Guidelines 

* 1 inch = 25.4 mm 
* Small journals: 119 mm wide (4.685 inch), 195 mm (7.677 inch) high (max)

graph combine EM WM EW WW, rows(2) ///
						  graphregion(margin(0 0 0 0)) ///
						  imargin(1 1 1 1) ///
						  scheme(lean1) ysize(4.685) xsize(7.677) name(Figure_1, replace)
						  
graph play grec/adjust-figure-DEMOGRAPHY-adjust-Figure-1.grec

graph export "${logDir}//Figure-1-WIDE.pdf", replace
graph export "${logDir}//Figure-1-WIDE.svg", replace
graph export "${logDir}//Figure-1-WIDE.eps", replace
*/

		
restore 	

/*----------------------------------------------------

  Calculate educational reproduction rates, joint effect. 
  
  Note: we use the program prospective_srr (see code above)

----------------------------------------------------*/

* A) PRODUCTION OF HIGH EDUCATED OFFSPRING
* Note: Jackknife estimation, therefore takes some time to execute.

* Save resampling data into ${tempDir}/repdat_anchor`anchor'_part`part'_coh`coh'
* Save estimation data into ${tempDir}/repest_anchor`anchor'_part`part'_coh`coh'
foreach anchor of numlist 1/2 {
	foreach part of numlist 1/2 {
		foreach coh of numlist 1/4 {
			preserve
				keep if anchor == `anchor' 
				keep if part == `part' 
				keep if coh == `coh'
				
				jackknife (Fertility: z0=e(z0) z1=e(z1) f0=e(f0) f1=e(f1) cfr0=e(cfr0) cfr1=e(cfr1)) ///
						  (Transmission: rp0=e(rp0) rp1=e(rp1) lnror=e(lnror)) ///
						  (Reproduction: sr00=e(sr00) sr11=e(sr11) te=e(te)) ///
						  (Counterfactual: sr01=e(sr01) sr10=e(sr10)) ///
						  (Decomposition: fe=e(fe) ieo=e(ieo) fe_rel=e(fe_rel)) ///
						  , n(e(N)) verbose ///
						  saving("${tempDir}/repdat_anchor`anchor'_part`part'_coh`coh'", replace): prospective_srr if anchor==`anchor' & part == `part' & coh==`coh'
				
				parmest, idstr("Anchor`anchor'Part`part'") idnum(`coh') saving("${tempDir}/repest_anchor`anchor'_part`part'_coh`coh'",replace)
			restore
		}
	}
}

* B) PRODUCTION OF LOW EDUCATED OFFSPRING
* Bootstrapping – caution! Takes long. 
* Save resampling data into ${tempDir}/repLOWdat_anchor`anchor'_part`part'_coh`coh'
* Save estimation data into ${tempDir}/repLOWest_anchor`anchor'_part`part'_coh`coh'

* Note – just revert the outcome
rename cabi OLDcabi 
gen cabi = OLDcabi == 0

foreach anchor of numlist 1/2 {
	foreach part of numlist 1/2 {
		foreach coh of numlist 1/4 {
			preserve
				keep if anchor == `anchor' 
				keep if part == `part' 
				keep if coh == `coh'
				
				jackknife (Fertility: z0=e(z0) z1=e(z1) f0=e(f0) f1=e(f1) cfr0=e(cfr0) cfr1=e(cfr1)) ///
						  (Transmission: rp0=e(rp0) rp1=e(rp1) lnror=e(lnror)) ///
						  (Reproduction: sr00=e(sr00) sr11=e(sr11) te=e(te)) ///
						  (Counterfactual: sr01=e(sr01) sr10=e(sr10)) ///
						  (Decomposition: fe=e(fe) ieo=e(ieo) fe_rel=e(fe_rel)) ///
						  , n(e(N)) verbose ///
						  saving("${tempDir}/repLOWdat_anchor`anchor'_part`part'_coh`coh'", replace): prospective_srr if anchor==`anchor' & part == `part' & coh==`coh'
				parmest, idstr("Anchor`anchor'Part`part'") idnum(`coh') saving("${tempDir}/repLOWest_anchor`anchor'_part`part'_coh`coh'",replace)
			restore
		}
	}
}

* undo the outcome reversal
drop cabi
rename OLDcabi cabi  


* Build dataset based on estimates

* 1) producing high educated offspring		
use 			"${tempDir}/repest_anchor1_part1_coh1", clear
append using	"${tempDir}/repest_anchor1_part1_coh2"	
append using	"${tempDir}/repest_anchor1_part1_coh3"	
append using	"${tempDir}/repest_anchor1_part1_coh4"

append using	"${tempDir}/repest_anchor1_part2_coh1"
append using	"${tempDir}/repest_anchor1_part2_coh2"
append using	"${tempDir}/repest_anchor1_part2_coh3"
append using	"${tempDir}/repest_anchor1_part2_coh4"

append using	"${tempDir}/repest_anchor2_part1_coh1"
append using	"${tempDir}/repest_anchor2_part1_coh2"
append using	"${tempDir}/repest_anchor2_part1_coh3"
append using	"${tempDir}/repest_anchor2_part1_coh4"	

append using	"${tempDir}/repest_anchor2_part2_coh1"
append using	"${tempDir}/repest_anchor2_part2_coh2"
append using	"${tempDir}/repest_anchor2_part2_coh3"
append using	"${tempDir}/repest_anchor2_part2_coh4"	

gen product = 1 // mark production of high educated offspring 

* 2) producing low educated offspring
append using	"${tempDir}/repLOWest_anchor1_part1_coh1"	
append using	"${tempDir}/repLOWest_anchor1_part1_coh2"	
append using	"${tempDir}/repLOWest_anchor1_part1_coh3"	
append using	"${tempDir}/repLOWest_anchor1_part1_coh4"	

append using	"${tempDir}/repLOWest_anchor1_part2_coh1"	
append using	"${tempDir}/repLOWest_anchor1_part2_coh2"	
append using	"${tempDir}/repLOWest_anchor1_part2_coh3"	
append using	"${tempDir}/repLOWest_anchor1_part2_coh4"	

append using	"${tempDir}/repLOWest_anchor2_part1_coh1"	
append using	"${tempDir}/repLOWest_anchor2_part1_coh2"	
append using	"${tempDir}/repLOWest_anchor2_part1_coh3"	
append using	"${tempDir}/repLOWest_anchor2_part1_coh4"	

append using	"${tempDir}/repLOWest_anchor2_part2_coh1"	
append using	"${tempDir}/repLOWest_anchor2_part2_coh2"	
append using	"${tempDir}/repLOWest_anchor2_part2_coh3"	
append using	"${tempDir}/repLOWest_anchor2_part2_coh4"

replace product = 0 if product >= .
lab def product 0 "low educated offspring" 1 "high educated offspring", modify
lab val product product

gen MEN = regexm(idstr,"Anchor1")
gen WEST = regexm(idstr,"Part2")
gen COH = idnum 
lab def coh 1 "1930-35" 2 "1936-40" 3 "1941-45" 4 "1946-50", modify
lab val COH coh 		


/*----------------------------------------------------

	FIGURE 4 – educational reproduction rates 
	
----------------------------------------------------*/
* Producing high educated offspring
* Men – East
twoway (scatter estimate COH if parm=="sr01" & product==1 &  MEN == 1 & WEST == 0, sort c(l) msymb(Dh) lpat(shortdash) col(gs8)) /// CF: high educated having fertility of low educated
	   (scatter estimate COH if parm=="sr10" & product==1 &  MEN == 1 & WEST == 0, sort c(l) msymb(Th) lpat(shortdash) col(gs8)) /// CF: low educated having fertility of high educated
	   (scatter estimate COH if parm=="sr00" & product==1 &  MEN == 1 & WEST == 0, sort c(l) msymb(T) col(black)) /// OBS: lower educated  
	   (scatter estimate COH if parm=="sr11" & product==1 &  MEN == 1 & WEST == 0, sort c(l) msymb(D) col(black)) /// OBS: higher educated
	   , legend(lab(1 "CF1: High but fertility of low") ///
				lab(2 "CF2: Low but fertility of high") ///
				lab(3 "Low-educated") ///
				lab(4 "High-educated") ///
				size(small) row(2) order(4 1 3  2) ring(0) pos(3)) ylabel(0(.25)1.75, grid) ///
				xlabel(,  val) ///
				ytitle("High-educated children") scheme(lean1) xtitle(Birth cohort) ///
				name(EM, replace) title("Men – East") graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 	
* Men – West				
twoway (scatter estimate COH if parm=="sr01" & product==1 &  MEN == 1 & WEST == 1, sort c(l) msymb(Dh) lpat(shortdash) col(gs8)) /// CF: high educated having fertility of low educated
	   (scatter estimate COH if parm=="sr10" & product==1 &  MEN == 1 & WEST == 1, sort c(l) msymb(Th) lpat(shortdash) col(gs8)) /// CF: low educated having fertility of high educated
	   (scatter estimate COH if parm=="sr00" & product==1 &  MEN == 1 & WEST == 1, sort c(l) msymb(T) col(black)) /// OBS: lower educated  
	   (scatter estimate COH if parm=="sr11" & product==1 &  MEN == 1 & WEST == 1, sort c(l) msymb(D) col(black)) /// OBS: higher educated
	   , legend(lab(1 "CF1: High but fertility of low") ///
				lab(2 "CF2: Low but fertility of high") ///
				lab(3 "Low-educated") ///
				lab(4 "High-educated") ///
				size(small) row(2) order(4 1 3  2) ring(0) pos(3)) ylabel(0(.25)1.75, grid) ///
				xlabel(,  val) ///
				ytitle("High-educated children") scheme(lean1) xtitle(Birth cohort) ///
				name(WM, replace) title("Men – West")	graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 
				
* Women – East
twoway (scatter estimate COH if parm=="sr01" & product==1 &  MEN == 0 & WEST == 0, sort c(l) msymb(Dh) lpat(shortdash) col(gs8)) /// CF: high educated having fertility of low educated
	   (scatter estimate COH if parm=="sr10" & product==1 &  MEN == 0 & WEST == 0, sort c(l) msymb(Th) lpat(shortdash) col(gs8)) /// CF: low educated having fertility of high educated
	   (scatter estimate COH if parm=="sr00" & product==1 &  MEN == 0 & WEST == 0, sort c(l) msymb(T) col(black)) /// OBS: lower educated  
	   (scatter estimate COH if parm=="sr11" & product==1 &  MEN == 0 & WEST == 0, sort c(l) msymb(D) col(black)) /// OBS: higher educated
	   , legend(lab(1 "CF1: High but fertility of low") ///
				lab(2 "CF2: Low but fertility of high") ///
				lab(3 "Low-educated") ///
				lab(4 "High-educated") ///
				size(small) row(2) order(4 1 3  2) ring(0) pos(3)) ylabel(0(.25)1.75, grid) ///
				xlabel(,  val) ///
				ytitle("High-educated children") scheme(lean1) xtitle(Birth cohort) ///
				name(EW, replace) title("Women – East")	graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 	 
* Women – West
twoway (scatter estimate COH if parm=="sr01" & product==1 &  MEN == 0 & WEST == 1, sort c(l) msymb(Dh) lpat(shortdash) col(gs8)) /// CF: high educated having fertility of low educated
	   (scatter estimate COH if parm=="sr10" & product==1 &  MEN == 0 & WEST == 1, sort c(l) msymb(Th) lpat(shortdash) col(gs8)) /// CF: low educated having fertility of high educated
	   (scatter estimate COH if parm=="sr00" & product==1 &  MEN == 0 & WEST == 1, sort c(l) msymb(T) col(black)) /// OBS: lower educated  
	   (scatter estimate COH if parm=="sr11" & product==1 &  MEN == 0 & WEST == 1, sort c(l) msymb(D) col(black)) /// OBS: higher educated
	   , legend(lab(1 "CF1: High but fertility of low") ///
				lab(2 "CF2: Low but fertility of high") ///
				lab(3 "Low-educated") ///
				lab(4 "High-educated") ///
				size(small) row(2) order(4 1 3  2) ring(0) pos(3)) ylabel(0(.25)1.75, grid) ///
				xlabel(,  val) ///
				ytitle("High-educated children") scheme(lean1) xtitle(Birth cohort) ///
				name(WW, replace) title("Women – West")	graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 

grc1leg EM WM EW WW, rows(2) legendfrom(EM) title("Producing high-educated offspring") xsize(10)  ysize(15) scheme(lean1) graphregion(margin(0 0 0 0)) imargin(5 5 5 5) iscale(*.8) name(high, replace)

* Producing low educated offspring
* Men – East
twoway (scatter estimate COH if parm=="sr01" & product==0 &  MEN == 1 & WEST == 0, sort c(l) msymb(Dh) lpat(shortdash) col(gs8)) /// CF: high educated having fertility of low educated
	   (scatter estimate COH if parm=="sr10" & product==0 &  MEN == 1 & WEST == 0, sort c(l) msymb(Th) lpat(shortdash) col(gs8)) /// CF: low educated having fertility of high educated
	   (scatter estimate COH if parm=="sr00" & product==0 &  MEN == 1 & WEST == 0, sort c(l) msymb(T) col(black)) /// OBS: lower educated  
	   (scatter estimate COH if parm=="sr11" & product==0 &  MEN == 1 & WEST == 0, sort c(l) msymb(D) col(black)) /// OBS: higher educated
	   , legend(lab(1 "CF1: High but fertility of low") ///
				lab(2 "CF2: Low but fertility of high") ///
				lab(3 "Low-educated") ///
				lab(4 "High-educated") ///
				size(small) row(2) order(4 1 3  2) ring(0) pos(3)) ylabel(0(.25)1.75, grid) ///
				xlabel(,  val) ///
				ytitle("Low-educated children") scheme(lean1) xtitle(Birth cohort) ///
				name(EM_l, replace) title("Men – East")	graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 
* Men – West				
twoway (scatter estimate COH if parm=="sr01" & product==0 &  MEN == 1 & WEST == 1, sort c(l) msymb(Dh) lpat(shortdash) col(gs8)) /// CF: high educated having fertility of low educated
	   (scatter estimate COH if parm=="sr10" & product==0 &  MEN == 1 & WEST == 1, sort c(l) msymb(Th) lpat(shortdash) col(gs8)) /// CF: low educated having fertility of high educated
	   (scatter estimate COH if parm=="sr00" & product==0 &  MEN == 1 & WEST == 1, sort c(l) msymb(T) col(black)) /// OBS: lower educated  
	   (scatter estimate COH if parm=="sr11" & product==0 &  MEN == 1 & WEST == 1, sort c(l) msymb(D) col(black)) /// OBS: higher educated
	   , legend(lab(1 "CF1: High but fertility of low") ///
				lab(2 "CF2: Low but fertility of high") ///
				lab(3 "Low-educated") ///
				lab(4 "High-educated") ///
				size(small) row(2) order(4 1 3  2) ring(0) pos(3)) ylabel(0(.25)1.75, grid) ///
				xlabel(,  val) ///
				ytitle("Low-educated children") scheme(lean1) xtitle(Birth cohort) ///
				name(WM_l, replace) title("Men – West")	graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 
				
* Women – East
twoway (scatter estimate COH if parm=="sr01" & product==0 &  MEN == 0 & WEST == 0, sort c(l) msymb(Dh) lpat(shortdash) col(gs8)) /// CF: high educated having fertility of low educated
	   (scatter estimate COH if parm=="sr10" & product==0 &  MEN == 0 & WEST == 0, sort c(l) msymb(Th) lpat(shortdash) col(gs8)) /// CF: low educated having fertility of high educated
	   (scatter estimate COH if parm=="sr00" & product==0 &  MEN == 0 & WEST == 0, sort c(l) msymb(T) col(black)) /// OBS: lower educated  
	   (scatter estimate COH if parm=="sr11" & product==0 &  MEN == 0 & WEST == 0, sort c(l) msymb(D) col(black)) /// OBS: higher educated
	   , legend(lab(1 "CF1: High but fertility of low") ///
				lab(2 "CF2: Low but fertility of high") ///
				lab(3 "Low-educated") ///
				lab(4 "High-educated") ///
				size(small) row(2) order(4 1 3  2) ring(0) pos(3)) ylabel(0(.25)1.75, grid) ///
				xlabel(,  val) ///
				ytitle("Low-educated children") scheme(lean1) xtitle(Birth cohort) ///
				name(EW_l, replace) title("Women – East")	graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 	 
* Women – West
twoway (scatter estimate COH if parm=="sr01" & product==0 &  MEN == 0 & WEST == 1, sort c(l) msymb(Dh) lpat(shortdash) col(gs8)) /// CF: high educated having fertility of low educated
	   (scatter estimate COH if parm=="sr10" & product==0 &  MEN == 0 & WEST == 1, sort c(l) msymb(Th) lpat(shortdash) col(gs8)) /// CF: low educated having fertility of high educated
	   (scatter estimate COH if parm=="sr00" & product==0 &  MEN == 0 & WEST == 1, sort c(l) msymb(T) col(black)) /// OBS: lower educated  
	   (scatter estimate COH if parm=="sr11" & product==0 &  MEN == 0 & WEST == 1, sort c(l) msymb(D) col(black)) /// OBS: higher educated
	   , legend(lab(1 "CF1: High but fertility of low") ///
				lab(2 "CF2: Low but fertility of high") ///
				lab(3 "Low-educated") ///
				lab(4 "High-educated") ///
				size(small) row(2) order(4 1 3  2) ring(0) pos(3)) ylabel(0(.25)1.75, grid) ///
				xlabel(,  val) ///
				ytitle("Low-educated children") scheme(lean1) xtitle(Birth cohort) ///
				name(WW_l, replace) title("Women – West")	graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 

grc1leg EM_l WM_l EW_l WW_l, rows(2) title("Producing low-educated offspring") legendfrom(EM_l) xsize(10)  ysize(15) scheme(lean1) graphregion(margin(0 0 0 0)) imargin(5 5 5 5) iscale(*.8) name(low, replace)

// different display - wide
grc1leg high low, cols(2) legendfrom(high) graphregion(margin(0 0 0 0)) imargin(2 2 2 2) scheme(lean1)
graph play grec/adjust-figure-reproduction-rates-wide.grec
graph play grec/adjust-figure-reproduction-rates-wide-2.grec
graph export "${logDir}/Figure_4-reproduction-rates.pdf", replace


/*
/* Alternative Figure design to fit the Demography layout */
// https://www.springer.com/journal/13524/submission-guidelines#Instructions%20for%20Authors_Artwork%20and%20Illustrations%20Guidelines 

* 1 inch = 25.4 mm 
* Small journals: 119 mm wide (4.685 inch), 195 mm (7.677 inch) high (max)

grc1leg EM WM EW WW, rows(2) legendfrom(EM) ///
			title("Producing high-educated offspring") xsize(10)  ysize(15) ///
			scheme(lean1) graphregion(margin(0 0 0 0)) imargin(2 2 2 2) ///
			name(high, replace)
grc1leg EM_l WM_l EW_l WW_l, rows(2) title("Producing low-educated offspring") ///
			legendfrom(EM_l) xsize(10)  ysize(15) scheme(lean1) ///
			graphregion(margin(0 0 0 0)) imargin(2 2 2 2) ///
			 name(low, replace)

grc1leg high low, rows(2) legendfrom(high) ///
						  graphregion(margin(0 0 0 0)) ///
						  imargin(2 2 2 2) ///
						  scheme(lean1) ysize(7.677) xsize(4.685) name(Figure_4, replace)
						  
graph display Figure_4, ysize(7.677) xsize(4.685) // fix for the xsize / ysize problem with grc1leg

graph play grec/adjust-figure-DEMOGRAPHY-remove-xtitles.grec
graph play grec/adjust-figure-DEMOGRAPHY-adjust-fontsizes.grec
graph play grec/adjust-figure-DEMOGRAPHY-remove-ytitle-in-second-column.grec

* Top-bottom graph
graph export "${logDir}/Figure-4-TOP-BOTTOM.pdf", replace
graph export "${logDir}/Figure-4-TOP-BOTTOM.svg", replace
graph export "${logDir}/Figure-4-TOP-BOTTOM.eps", replace

* Wide graph
graph play grec/adjust-figure-DEMOGRAPHY-reshape-to-wide.grec
graph export "${logDir}/Figure-4-WIDE.pdf", replace
graph export "${logDir}/Figure-4-WIDE.svg", replace
graph export "${logDir}/Figure-4-WIDE.eps", replace

*/

/*-------------------------------------

FIGURE 5 - joint effects

-------------------------------------*/

* High educated offspring
* Total
twoway (scatter estimate COH if parm=="te" & product==1 &  MEN == 0 & WEST == 1, sort c(l) msymb(O) lpat(solid) col(cranberry)) /// 
	   (scatter estimate COH if parm=="te" & product==1 &  MEN == 1 & WEST == 1, sort c(l) msymb(D) lpat(solid) col(blue)) /// 
	   (scatter estimate COH if parm=="te" & product==1 &  MEN == 0 & WEST == 0, sort c(l) msymb(O) lpat(shortdash) col(cranberry)) ///
	   (scatter estimate COH if parm=="te" & product==1 &  MEN == 1 & WEST == 0, sort c(l) msymb(D) lpat(shortdash) col(blue)) ///
	   , legend(lab(1 "Women - West") ///
				lab(2 "Men – West") ///
				lab(3 "Women - East") ///
				lab(4 "Men – East") ///
				size(small) row(2) order(4 1 3  2) ring(0) pos(4)) ylabel(.25(.25)1, grid) ///
				xlabel(,  val) ///
				ytitle("difference in rates (high vs. low)") scheme(lean1) xtitle(Birth cohort) ///
				name(joint_effects, replace) title("Joint effect")	graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 
	
* fertility 
twoway (scatter estimate COH if parm=="fe" & product==1 &  MEN == 0 & WEST == 1, sort c(l) msymb(O) lpat(solid) col(cranberry)) /// 
	   (scatter estimate COH if parm=="fe" & product==1 &  MEN == 1 & WEST == 1, sort c(l) msymb(D) lpat(solid) col(blue)) /// 
	   (scatter estimate COH if parm=="fe" & product==1 &  MEN == 0 & WEST == 0, sort c(l) msymb(O) lpat(shortdash) col(cranberry)) ///
	   (scatter estimate COH if parm=="fe" & product==1 &  MEN == 1 & WEST == 0, sort c(l) msymb(D) lpat(shortdash) col(blue)) ///
	   , legend(lab(1 "Women - West") ///
				lab(2 "Men – West") ///
				lab(3 "Women - East") ///
				lab(4 "Men – East") ///
				size(small) row(2) order(4 1 3  2) ring(0) pos(2)) ylabel(-.25(.25).25, grid) ///
				xlabel(,  val) ///
				ytitle("difference in rates (high vs. low)") scheme(lean1) xtitle(Birth cohort) ///
				name(fe_effect, replace) title("Fertility effect")	graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 
* mobility 		
twoway (scatter estimate COH if parm=="ieo" & product==1 &  MEN == 0 & WEST == 1, sort c(l) msymb(O) lpat(solid) col(cranberry)) /// 
	   (scatter estimate COH if parm=="ieo" & product==1 &  MEN == 1 & WEST == 1, sort c(l) msymb(D) lpat(solid) col(blue)) /// 
	   (scatter estimate COH if parm=="ieo" & product==1 &  MEN == 0 & WEST == 0, sort c(l) msymb(O) lpat(shortdash) col(cranberry)) ///
	   (scatter estimate COH if parm=="ieo" & product==1 &  MEN == 1 & WEST == 0, sort c(l) msymb(D) lpat(shortdash) col(blue)) ///
	   , legend(lab(1 "Women - West") ///
				lab(2 "Men – West") ///
				lab(3 "Women - East") ///
				lab(4 "Men – East") ///
				size(small) row(2) order(4 1 3  2) ring(0) pos(4)) ylabel(.25(.25)1, grid) ///
				xlabel(,  val) ///
				ytitle("difference in rates (high vs. low)") scheme(lean1) xtitle(Birth cohort) ///
				name(ieo_effect, replace) title("Mobility effect")	graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 

* Show joint effects and mobility effects in one graph
* Producing high educated offspring 
twoway (scatter estimate COH if parm=="te" 	& product==1 &  MEN == 1 & WEST == 1, sort c(l) msymb(O) lpat(solid) col(black)) /// 
	   (scatter estimate COH if parm=="ieo" & product==1 &  MEN == 1 & WEST == 1, sort c(l) msymb(Oh) lpat(shortdash) col(gs8)) /// 
	   , legend(lab(1 "Joint effect") ///
				lab(2 "Mobility effect") ///
				size(small) row(1) order(1 2) ring(0) pos(4)) ylabel(0(.25)1, grid) ///
				xlabel(,  val) ///
				ytitle("Difference in rates (high vs. low)") scheme(lean1) xtitle("") ///
				name(WM, replace) title("Joint effect")	title("Men – West") graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 
twoway (scatter estimate COH if parm=="te" 	& product==1 &  MEN == 0 & WEST == 1, sort c(l) msymb(O) lpat(solid) col(black)) /// 
	   (scatter estimate COH if parm=="ieo" & product==1 &  MEN == 0 & WEST == 1, sort c(l) msymb(Oh) lpat(shortdash) col(gs8)) /// 
	   , legend(lab(1 "Joint effect") ///
				lab(2 "Mobility effect") ///
				size(small) row(1) order(1 2) ring(0) pos(4)) ylabel(0(.25)1, grid) ///
				xlabel(,  val) ///
				ytitle("Difference in rates (high vs. low)") scheme(lean1) xtitle("") ///
				name(WW, replace) title("Joint effect")	title("Women – West") graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 				
twoway (scatter estimate COH if parm=="te" 	& product==1 &  MEN == 1 & WEST == 0, sort c(l) msymb(O) lpat(solid) col(black)) /// 
	   (scatter estimate COH if parm=="ieo" & product==1 &  MEN == 1 & WEST == 0, sort c(l) msymb(Oh) lpat(shortdash) col(gs8)) /// 
	   , legend(lab(1 "Joint effect") ///
				lab(2 "Mobility effect") ///
				size(small) row(1) order(1 2) ring(0) pos(4)) ylabel(0(.25)1, grid) ///
				xlabel(,  val) ///
				ytitle("Difference in rates (high vs. low)") scheme(lean1) xtitle("") ///
				name(EM, replace) title("Joint effect")	title("Men – East") graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 
twoway (scatter estimate COH if parm=="te" 	& product==1 &  MEN == 0 & WEST == 0, sort c(l) msymb(O) lpat(solid) col(black)) /// 
	   (scatter estimate COH if parm=="ieo" & product==1 &  MEN == 0 & WEST == 0, sort c(l) msymb(Oh) lpat(shortdash) col(gs8)) /// 
	   , legend(lab(1 "Joint effect") ///
				lab(2 "Mobility effect") ///
				size(small) row(1) order(1 2) ring(0) pos(4)) ylabel(0(.25)1, grid) ///
				xlabel(,  val) ///
				ytitle("Difference in rates (high vs. low)") scheme(lean1) xtitle("") ///
				name(EW, replace) title("Joint effect")	title("Women – East") graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 

* Producing low educated offspring	
twoway (scatter estimate COH if parm=="te" 	& product==0 &  MEN == 1 & WEST == 1, sort c(l) msymb(O) lpat(solid) col(black)) /// 
	   (scatter estimate COH if parm=="ieo" & product==0 &  MEN == 1 & WEST == 1, sort c(l) msymb(Oh) lpat(shortdash) col(gs8)) /// 
	   , legend(lab(1 "Joint effect") ///
				lab(2 "Mobility effect") ///
				size(small) row(1) order(1 2) ring(0) pos(4)) ylabel(-1.25(.25)-.25, grid) ///
				xlabel(,  val) ///
				ytitle("Difference in rates (high vs. low)") scheme(lean1) xtitle("") ///
				name(WM_l, replace) title("Joint effect")	title("Men – West") graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 
twoway (scatter estimate COH if parm=="te" 	& product==0 &  MEN == 0 & WEST == 1, sort c(l) msymb(O) lpat(solid) col(black)) /// 
	   (scatter estimate COH if parm=="ieo" & product==0 &  MEN == 0 & WEST == 1, sort c(l) msymb(Oh) lpat(shortdash) col(gs8)) /// 
	   , legend(lab(1 "Joint effect") ///
				lab(2 "Mobility effect") ///
				size(small) row(1) order(1 2) ring(0) pos(4)) ylabel(-1.25(.25)-.25, grid) ///
				xlabel(,  val) ///
				ytitle("Difference in rates (high vs. low)") scheme(lean1) xtitle("") ///
				name(WW_l, replace) title("Joint effect")	title("Women – West")	graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 			
twoway (scatter estimate COH if parm=="te" 	& product==0 &  MEN == 1 & WEST == 0, sort c(l) msymb(O) lpat(solid) col(black)) /// 
	   (scatter estimate COH if parm=="ieo" & product==0 &  MEN == 1 & WEST == 0, sort c(l) msymb(Oh) lpat(shortdash) col(gs8)) /// 
	   , legend(lab(1 "Joint effect") ///
				lab(2 "Mobility effect") ///
				size(small) row(1) order(1 2) ring(0) pos(4)) ylabel(-1.25(.25)-.25, grid) ///
				xlabel(,  val) ///
				ytitle("Difference in rates (high vs. low)") scheme(lean1) xtitle("") ///
				name(EM_l, replace) title("Joint effect")	title("Men – East") graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 
twoway (scatter estimate COH if parm=="te" 	& product==0 &  MEN == 0 & WEST == 0, sort c(l) msymb(O) lpat(solid) col(black)) /// 
	   (scatter estimate COH if parm=="ieo" & product==0 &  MEN == 0 & WEST == 0, sort c(l) msymb(Oh) lpat(shortdash) col(gs8)) /// 
	   , legend(lab(1 "Joint effect") ///
				lab(2 "Mobility effect") ///
				size(small) row(1) order(1 2) ring(0) pos(4)) ylabel(-1.25(.25)-.25, grid) ///
				xlabel(,  val) ///
				ytitle("Difference in rates (high vs. low)") scheme(lean1) xtitle("") ///
				name(EW_l, replace) title("Joint effect")	title("Women – East") graphregion(fcolor(none) lcolor(none)) plotregion(fcolor(none) lcolor(black)) 

grc1leg EM WM EW WW, rows(2) legendfrom(EM) title("Producing high educated offspring") xsize(10)  ysize(15) scheme(lean1) graphregion(margin(0 0 0 0) lwidth(none) color(none)) imargin(5 5 5 5) iscale(*.8) name(high, replace)
grc1leg EM_l WM_l EW_l WW_l, rows(2) title("Producing low educated offspring") legendfrom(EM_l) xsize(10)  ysize(15) scheme(lean1) graphregion(margin(0 0 0 0) lwidth(none) color(none)) imargin(5 5 5 5) iscale(*.8) name(low, replace)

* combine graph
/*
grc1leg high low, rows(2) legendfrom(high) graphregion(margin(0 0 0 0)) imargin(0 0 0 0) scheme(lean1)
* adjust graph using recording
graph play adjust-figure-reproduction-rates.grec

graph export figures/Figure-XX-joint-effects.pdf, replace
*/

grc1leg high low, cols(2) legendfrom(high) ///
		graphregion(margin(0 0 0 0) lwidth(none) color(none)) imargin(2 2 2 2) scheme(lean1)
graph play grec/adjust-figure-joint-effects-wide.grec
graph export "${logDir}/Figure_5-joint-effects.pdf", replace

/*
/* Alternative Figure design to fit the Demography layout */
// https://www.springer.com/journal/13524/submission-guidelines#Instructions%20for%20Authors_Artwork%20and%20Illustrations%20Guidelines 

* 1 inch = 25.4 mm 
* Small journals: 119 mm wide (4.685 inch), 195 mm (7.677 inch) high (max)

grc1leg EM WM EW WW, rows(2) legendfrom(EM) ///
			title("Producing high-educated offspring") xsize(10)  ysize(15) ///
			scheme(lean1) graphregion(margin(0 0 0 0) lwidth(none) color(none)) imargin(2 2 2 2) ///
			name(high, replace)
grc1leg EM_l WM_l EW_l WW_l, rows(2) title("Producing low-educated offspring") ///
			legendfrom(EM_l) xsize(10)  ysize(15) scheme(lean1) ///
			graphregion(margin(0 0 0 0) lwidth(none) color(none)) imargin(2 2 2 2) ///
			 name(low, replace)

grc1leg high low, rows(2) legendfrom(high) ///
						  graphregion(margin(0 0 0 0)) ///
						  imargin(2 2 2 2) ///
						  scheme(lean1) ysize(7.677) xsize(4.685) name(Figure_5, replace)
						  
graph display Figure_5, ysize(7.677) xsize(4.685) // fix for the xsize / ysize problem with grc1leg

graph play grec/adjust-figure-DEMOGRAPHY-remove-xtitles.grec
graph play grec/adjust-figure-DEMOGRAPHY-adjust-fontsizes.grec
graph play grec/adjust-figure-DEMOGRAPHY-remove-ytitle-in-second-column.grec

* Top-bottom graph
graph export "${logDir}//Figure-5-TOP-BOTTOM.pdf", replace
graph export "${logDir}//Figure-5-TOP-BOTTOM.svg", replace
graph export "${logDir}//Figure-5-TOP-BOTTOM.eps", replace

* Wide graph
graph play grec/adjust-figure-DEMOGRAPHY-reshape-to-wide.grec
graph export "${logDir}//Figure-5-WIDE.pdf", replace
graph export "${logDir}//Figure-5-WIDE.svg", replace
graph export "${logDir}//Figure-5-WIDE.eps", replace

*/


/*-------------------------------------

APPENDIX TABLES 

-------------------------------------*/

** Statistical significance – Joint, mobility and fertility effects **

format %9.3f estimate p
sort WEST MEN COH

* Producing high educated offspring 
* rates 
li  WEST MEN COH estimate p  if parm=="sr00"& product == 1, noobs clean  // & p < .05
li  WEST MEN COH estimate p  if parm=="sr11"& product == 1, noobs clean  // & p < .05

li  WEST MEN COH estimate p  if parm=="te"& product == 1, noobs clean  // & p < .05
li  WEST MEN COH estimate p  if parm=="ieo"& product == 1, noobs clean  // & p < .05
li  WEST MEN COH estimate p  if parm=="fe"& product == 1, noobs clean  // & p < .05

* Producing low educated offspring 
li  WEST MEN COH estimate p  if parm=="sr00"& product == 0, noobs clean  // & p < .05
li  WEST MEN COH estimate p  if parm=="sr11"& product == 0, noobs clean  // & p < .05

li  WEST MEN COH estimate p  if parm=="te"& product == 0, noobs clean  // & p < .05
li  WEST MEN COH estimate p  if parm=="ieo"& product == 0, noobs clean  // & p < .05
li  WEST MEN COH estimate p  if parm=="fe"& product == 0, noobs clean  // & p < .05



/*-----------------------------------------------------------

Table B4 (Rates of educational reproduction 
		  by part of Germany, gender, cohort)

-----------------------------------------------------------*/

log using "${logDir}/Table_B4-rates-of-educational-reproduction.smcl", replace

* TABLE B4 - Rates of educational reproduction by part of Germany, gender, cohort.
* (1) East-Germany 
* (1.1) Women 
* (1.1.1) Low education LOW -> producing low educated offspring (C_L)
li  COH estimate p  if parm=="sr00" & product == 0 & MEN==0 & WEST==0, noobs clean 
* (1.1.2) Low education LOW -> producing high educated offspring (C_H)
li  COH estimate p  if parm=="sr00" & product == 1 & MEN==0 & WEST==0, noobs clean 
* (1.1.3) High education HIGH -> producing low educated offspring (C_L)
li  COH estimate p  if parm=="sr11" & product == 0 & MEN==0 & WEST==0, noobs clean 
* (1.1.4) High education HIGH -> producing high educated offspring (C_H)
li  COH estimate p  if parm=="sr11" & product == 1 & MEN==0 & WEST==0, noobs clean 
* (1.2) Men 
* (1.2.1) Low education LOW -> producing low educated offspring (C_L)
li  COH estimate p  if parm=="sr00" & product == 0 & MEN==1 & WEST==0, noobs clean 
* (1.2.2) Low education LOW -> producing high educated offspring (C_H)
li  COH estimate p  if parm=="sr00" & product == 1 & MEN==1 & WEST==0, noobs clean 
* (1.2.3) High education HIGH -> producing low educated offspring (C_L)
li  COH estimate p  if parm=="sr11" & product == 0 & MEN==1 & WEST==0, noobs clean 
* (1.2.4) High education HIGH -> producing high educated offspring (C_H)
li  COH estimate p  if parm=="sr11" & product == 1 & MEN==1 & WEST==0, noobs clean 
* (2) West-Germany 
* (2.1) Women 
* (2.1.1) Low education LOW -> producing low educated offspring (C_L)
li  COH estimate p  if parm=="sr00" & product == 0 & MEN==0 & WEST==1, noobs clean 
* (2.1.2) Low education LOW -> producing high educated offspring (C_H)
li  COH estimate p  if parm=="sr00" & product == 1 & MEN==0 & WEST==1, noobs clean 
* (2.1.3) High education HIGH -> producing low educated offspring (C_L)
li  COH estimate p  if parm=="sr11" & product == 0 & MEN==0 & WEST==1, noobs clean 
* (2.1.4) High education HIGH -> producing high educated offspring (C_H)
li  COH estimate p  if parm=="sr11" & product == 1 & MEN==0 & WEST==1, noobs clean 
* (2.2) Men 
* (2.2.1) Low education LOW -> producing low educated offspring (C_L)
li  COH estimate p  if parm=="sr00" & product == 0 & MEN==1 & WEST==1, noobs clean 
* (2.2.2) Low education LOW -> producing high educated offspring (C_H)
li  COH estimate p  if parm=="sr00" & product == 1 & MEN==1 & WEST==1, noobs clean 
* (2.2.3) High education HIGH -> producing low educated offspring (C_L)
li  COH estimate p  if parm=="sr11" & product == 0 & MEN==1 & WEST==1, noobs clean 
* (2.2.4) High education HIGH -> producing high educated offspring (C_H)
li  COH estimate p  if parm=="sr11" & product == 1 & MEN==1 & WEST==1, noobs clean 

log close

/*-----------------------------------------------------------

Table B5 (Joint effect, mobility effect, and fertility effect in producing 
		  high educated offspring, by part of Germany, gender, cohort)

-----------------------------------------------------------*/

log using "${logDir}/Table_B5-decomposition-high-educated-offspring.smcl", replace


* (1) East-Germany 
* (1.1) Women 
* - Joint effect
li  COH estimate p if parm=="te" & product == 1 & MEN==0 & WEST==0, noobs clean 
* - Mobility effect
li  COH estimate p if parm=="ieo" & product == 1 & MEN==0 & WEST==0, noobs clean 
* - Fertility effect 
li  COH estimate p if parm=="fe" & product == 1 & MEN==0 & WEST==0, noobs clean 
* - % Fertility
li  COH estimate if parm=="fe_rel" & product == 1 & MEN==0 & WEST==0, noobs clean 
* (1.2) Men 
* - Joint effect
li  COH estimate p if parm=="te" & product == 1 & MEN==1 & WEST==0, noobs clean 
* - Mobility effect
li  COH estimate p if parm=="ieo" & product == 1 & MEN==1 & WEST==0, noobs clean 
* - Fertility effect 
li  COH estimate p if parm=="fe" & product == 1 & MEN==1 & WEST==0, noobs clean 
* - % Fertility
li  COH estimate if parm=="fe_rel" & product == 1 & MEN==1 & WEST==0, noobs clean 
* (2) West-Germany 
* (2.1) Women 
* - Joint effect
li  COH estimate p if parm=="te" & product == 1 & MEN==0 & WEST==1, noobs clean 
* - Mobility effect
li  COH estimate p if parm=="ieo" & product == 1 & MEN==0 & WEST==1, noobs clean 
* - Fertility effect 
li  COH estimate p if parm=="fe" & product == 1 & MEN==0 & WEST==1, noobs clean 
* - % Fertility
li  COH estimate if parm=="fe_rel" & product == 1 & MEN==0 & WEST==1, noobs clean 
* (2.2) Men 
* - Joint effect
li  COH estimate p if parm=="te" & product == 1 & MEN==1 & WEST==1, noobs clean 
* - Mobility effect
li  COH estimate p if parm=="ieo" & product == 1 & MEN==1 & WEST==1, noobs clean 
* - Fertility effect 
li  COH estimate p if parm=="fe" & product == 1 & MEN==1 & WEST==1, noobs clean 
* - % Fertility
li  COH estimate if parm=="fe_rel" & product == 1 & MEN==1 & WEST==1, noobs clean 

log close

/*-----------------------------------------------------------

Table B6 (Joint effect, mobility effect, and fertility effect in 
		  producing low educated offspring, by part of Germany, gender, cohort)

-----------------------------------------------------------*/

log using "${logDir}/Table_B6-decomposition-low-educated-offspring.smcl", replace


* (1) East-Germany 
* (1.1) Women 
* - Joint effect
li  COH estimate p if parm=="te" & product == 0 & MEN==0 & WEST==0, noobs clean 
* - Mobility effect
li  COH estimate p if parm=="ieo" & product == 0 & MEN==0 & WEST==0, noobs clean 
* - Fertility effect 
li  COH estimate p if parm=="fe" & product == 0 & MEN==0 & WEST==0, noobs clean 
* - % Fertility
li  COH estimate if parm=="fe_rel" & product == 0 & MEN==0 & WEST==0, noobs clean 
* (1.2) Men 
* - Joint effect
li  COH estimate p if parm=="te" & product == 0 & MEN==1 & WEST==0, noobs clean 
* - Mobility effect
li  COH estimate p if parm=="ieo" & product == 0 & MEN==1 & WEST==0, noobs clean 
* - Fertility effect 
li  COH estimate p if parm=="fe" & product == 0 & MEN==1 & WEST==0, noobs clean 
* - % Fertility
li  COH estimate if parm=="fe_rel" & product == 0 & MEN==1 & WEST==0, noobs clean 
* (2) West-Germany 
* (2.1) Women 
* - Joint effect
li  COH estimate p if parm=="te" & product == 0 & MEN==0 & WEST==1, noobs clean 
* - Mobility effect
li  COH estimate p if parm=="ieo" & product == 0 & MEN==0 & WEST==1, noobs clean 
* - Fertility effect 
li  COH estimate p if parm=="fe" & product == 0 & MEN==0 & WEST==1, noobs clean 
* - % Fertility
li  COH estimate if parm=="fe_rel" & product == 0 & MEN==0 & WEST==1, noobs clean 
* (2.2) Men 
* - Joint effect
li  COH estimate p if parm=="te" & product == 0 & MEN==1 & WEST==1, noobs clean 
* - Mobility effect
li  COH estimate p if parm=="ieo" & product == 0 & MEN==1 & WEST==1, noobs clean 
* - Fertility effect 
li  COH estimate p if parm=="fe" & product == 0 & MEN==1 & WEST==1, noobs clean 
* - % Fertility
li  COH estimate if parm=="fe_rel" & product == 0 & MEN==1 & WEST==1, noobs clean 

log close


/*------------------------------------------------------------------------------

  Part B) Population renewal models – consequences of differential fertility
		  
------------------------------------------------------------------------------*/

clear


* small helper program that does all the calculations
capt program drop _calc_cf 
program define _calc_cf, eclass
	syntax, title(string) anchor(integer) part(integer) coh(integer)
	quiet {
	keep if anchor == `anchor' 
	keep if part == `part' 
	keep if coh == `coh'
	
	// 1) % of H schooling in G2
	// Distribution of education among east german respondents in the fathers' sample
	fre cabi if anchor==`anchor' & part == `part' & coh == `coh' [aw=sw]
	* adjusted for data
	logit cabi c.data if anchor==`anchor' & part == `part' & coh == `coh' [pw=sw]
	margins , at(data=.5) post // % 34.8
	local H_G2_obs = _b[_cons]
	
	// 2) Distribution of schooling in G1 (the previous generation including all parents and non-parents)
	* (to be consistent with the paper this actually  should be labeld C1 as these contain per weighting all persons including non-parents)
	tab parabi if anchor==`anchor' & part == `part' & coh == `coh' [aw=sw*fsw*cw], matcell(G1)
	/*
		Matrix G1
				1
		1	# of low educated 	-> G[1,1]
		2	# of high educated	-> G[2,1]
	*/
	local N_G1 = G1[1,1]+G1[2,1] 
	local H_G1 = G1[2,1]/`N_G1'
	
	// 3) Inequality - observed, Odds ratio
	
	* calculate observed and counterfactual prospective rates of educational reproduction, 
	* joint effects as well as fertility and mobility components, fertility & childlessness.  
	prospective_srr if anchor==`anchor' & part == `part' & coh == `coh'
	
	* Store results in matrices for later use
	
	* Matrix robs: Observed rates of reproduction 
	/* 
		structure: 
					Outcome:	 
					(1) low ed.			(2) high ed.
						children			children
						
		(1) Low			sr000				sr00	
		
		(2) High		sr011				sr11	
		
		robs[1,1]	=> sr000 => # of low educated children low educated persons produce
		robs[1,2]	=> sr00	 =>	# of high educated children low educated persons produce
		robs[2,1]	=> sr011 => # of low educated children high educated persons produce
		robs[2,2]	=> sr11  => # of high educated children high educated persons produce
	*/
	mat robs = (`e(sr000)', `e(sr00)') \ (`e(sr011)', `e(sr11)')
	
	* counterfactual scenarios: 
	* Matrices: rs1, rs2, rs3, rs4
	/*
		rs1 -> if H had fertility of L 
		rs2 -> if L had fertility of H 
		rs3 -> if H had behaviour of L (behaviour means 'mobility behaviour')
		rs4 -> if L had behaviour of H (behaviour means 'mobility behaviour')
	*/
	// 1) if H had fertility of L 
	mat rs1 = (`e(sr000)', `e(sr00)') \ (`e(sr001)', `e(sr01)')
	// 2) if L had fertility of H 
	mat rs2 = (`e(sr010)', `e(sr10)') \ (`e(sr011)', `e(sr11)')
	// 3) if H had behaviour of L 
	mat rs3 = (`e(sr000)', `e(sr00)') \ (`e(sr010)', `e(sr10)')
	// 4) if L had behaviour of H 
	mat rs4 = (`e(sr001)', `e(sr01)') \ (`e(sr011)', `e(sr11)')

	// Mobility table, Intergenerational growth (G1_perc), G2 educational distriubtion (H_perc), 
	// Inequality measured by log-odds ratio calculated from the mobility table (lnOR)
	
	* observed 
	* Matrix O: observed mobility table 
	/*
		Structure
					Children
					low			high		
		Parents
		1	low		 #a			#b
		
		2	high	 #c			#d
		
		O[1,1]	-> a -> # of children with low education and low educated parents
		O[1,2]	-> b -> # of children with high education and low educated parents
		O[2,1]	-> c -> # of children with low education and high educated parents
		O[2,2]	-> d -> # of children with high education and high educated parents
		
	*/
	mat O = (G1[1,1]*robs[1,1], G1[1,1]*robs[1,2]) \ (G1[2,1]*robs[2,1], G1[2,1]*robs[2,2])
	
	* G1_perc: 100* G2/G1	(note: G1 here means C1 in the paper, the population that has produced G2)
	/*
			100   x    (number of G2 offspring)/(number of C1 persons)
	*/
	local G1_perc = 100*(O[1,1]+O[1,2]+O[2,1]+O[2,2])/`N_G1'
	
	* Inequality measure (1): Log-odds ratio 
	/*
	
	Odds ratio:
	
			odds of high education for children 
				from high educated parents 
				
			/ 
			
			odds of high education for children 
				from low educated parents 
				
	Then, log of the odds ratio. 
	*/
	local lnOR = ln((O[2,2]/O[2,1]) / ( O[1,2] / O[1,1]))
	
	* Inequality measure (2): Difference in attainment probability (children from high versus low educated parents)
	local probdiff = O[2,2]/(O[2,2]+O[2,1]) - O[1,2]/(O[1,2]+O[1,1])
	
	* Educational distribution 
	/*
		% of children having high education
	*/
	local H_perc = 100*(O[1,2]+O[2,2]) / (O[1,1]+O[1,2]+O[2,1]+O[2,2])
	
	* Repeat that for the hypothetical / counterfactual scenarious (using matrices rs1-rs4)
	* Scenario 1-4
	foreach num of numlist 1/4 { 
		mat S`num' = (G1[1,1]*rs`num'[1,1], G1[1,1]*rs`num'[1,2]) \ (G1[2,1]*rs`num'[2,1], G1[2,1]*rs`num'[2,2]) 
		local S`num'_G1_perc = 100*(S`num'[1,1]+S`num'[1,2]+S`num'[2,1]+S`num'[2,2])/`N_G1'
		local S`num'_lnOR = ln((S`num'[2,2]/S`num'[2,1]) / ( S`num'[1,2] / S`num'[1,1]))
		local S`num'_probdiff = S`num'[2,2]/(S`num'[2,2]+S`num'[2,1]) - S`num'[1,2]/(S`num'[1,2]+S`num'[1,1])
		local S`num'_H_perc = 100*(S`num'[1,2]+S`num'[2,2]) / (S`num'[1,1]+S`num'[1,2]+S`num'[2,1]+S`num'[2,2])
	}
	}
	#delimit ;
	display as txt "================="  _newline
				   "`title'"  _newline
				   "================="  _newline
				   "G1: " _newline
				   "L: " as res %9.2f (100*(1-`H_G1')) as txt _newline
				   "H: " as res %9.2f (100*`H_G1') 	   as txt _newline
				   "G2: " _newline
				   "--- as observed ---" as txt _newline
				   "H (%): " as res %9.2f (`H_perc') as txt _newline
				   "G1 (%): " as res %9.2f (`G1_perc') as txt _newline
				   "lnOR: " as res %9.2f (`lnOR') as txt _newline
				   "prob-diff: " as res %9.2f (`probdiff') as txt _newline
				   "--- S1: If H had fertility of L ---" as txt _newline
				   "H (%): " as res %9.2f (`S1_H_perc') as txt _newline
				   "G1 (%): " as res %9.2f (`S1_G1_perc') as txt _newline
				   "lnOR: " as res %9.2f (`S1_lnOR') as txt _newline
				   "prob-diff: " as res %9.2f (`S1_probdiff') as txt _newline
				   "--- S2: If L had fertility of H ---" as txt _newline
				   "H (%): " as res %9.2f (`S2_H_perc') as txt _newline
				   "G1 (%): " as res %9.2f (`S2_G1_perc') as txt _newline
				   "lnOR: " as res %9.2f (`S2_lnOR') as txt _newline
				   "prob-diff: " as res %9.2f (`S2_probdiff') as txt _newline
				   "--- S3: if H had behaviour of L ---" as txt _newline
				   "H (%): " as res %9.2f (`S3_H_perc') as txt _newline
				   "G1 (%): " as res %9.2f (`S3_G1_perc') as txt _newline
				   "lnOR: " as res %9.2f (`S3_lnOR') as txt _newline
				   "prob-diff: " as res %9.2f (`S3_probdiff') as txt _newline
				   "--- S4: if L had behaviour of H  ---" as txt _newline
				   "H (%): " as res %9.2f (`S4_H_perc') as txt _newline
				   "G1 (%): " as res %9.2f (`S4_G1_perc') as txt _newline
				   "lnOR: " as res %9.2f (`S4_lnOR') as txt _newline
				   "prob-diff: " as res %9.2f (`S4_probdiff') as txt _newline
				   ;
				   
	#delimit cr 
	
	// return population matrices / mobility tables (based on which odds ratios are calculated)
	mat matO = O 
	mat matS1 = S1
	mat matS2 = S2
	mat matS3 = S3
	mat matS4 = S4
	
	// ereturn clear
	// Observed 
	ereturn scalar obs_Hperc = `H_perc'
	ereturn scalar obs_G1perc = `G1_perc'
	ereturn scalar obs_lnOR = `lnOR'
	ereturn scalar obs_probdiff = `probdiff'
	
	// S1: If H had fertility of L
	ereturn scalar S1_Hperc		= `S1_H_perc'
	ereturn scalar S1_G1perc	= `S1_G1_perc'
	ereturn scalar S1_lnOR		= `S1_lnOR'
	ereturn scalar S1_probdiff  = `S1_probdiff'
	
	// S2: If L had fertility of H
	ereturn scalar S2_Hperc		= `S2_H_perc'
	ereturn scalar S2_G1perc	= `S2_G1_perc'
	ereturn scalar S2_lnOR		= `S2_lnOR'
	ereturn scalar S2_probdiff  = `S2_probdiff'
	
	// S3: if H had behaviour of L
	ereturn scalar S3_Hperc		= `S3_H_perc'
	ereturn scalar S3_G1perc	= `S3_G1_perc'
	ereturn scalar S3_lnOR		= `S3_lnOR'
	ereturn scalar S3_probdiff  = `S3_probdiff'
	
	// S4: if L had behaviour of H
	ereturn scalar S4_Hperc		= `S4_H_perc'
	ereturn scalar S4_G1perc	= `S4_G1_perc'
	ereturn scalar S4_lnOR		= `S4_lnOR'
	ereturn scalar S4_probdiff  = `S4_probdiff'
	
	mat obs = (0, `anchor', `part', `coh', `H_perc', `G1_perc', `lnOR', `probdiff')
	mat S1 =  (1, `anchor', `part', `coh', `S1_H_perc', `S1_G1_perc', `S1_lnOR', `S1_probdiff')
	mat S2 =  (2, `anchor', `part', `coh', `S2_H_perc', `S2_G1_perc', `S2_lnOR', `S2_probdiff')
	mat S3 =  (3, `anchor', `part', `coh', `S3_H_perc', `S3_G1_perc', `S3_lnOR', `S3_probdiff')
	mat S4 =  (4, `anchor', `part', `coh', `S4_H_perc', `S4_G1_perc', `S4_lnOR', `S4_probdiff')
	
	mat ret = obs \ S1 \ S2 \ S3 \ S4
	mat rownames ret = obs S1 S2 S3 S4
	mat colnames ret = scenario anchor part coh  H_perc G1_perc lnOR probdiff
	
	
	
	ereturn matrix ret = ret
	ereturn matrix matO = matO
	ereturn matrix matS1 = matS1
	ereturn matrix matS2 = matS2
	ereturn matrix matS3 = matS3
	ereturn matrix matS4 = matS4
end 



/*-----------------------------------------------------------

Calculate indicators

-----------------------------------------------------------*/



foreach coh of numlist 1/4 {
	use "${tempDir}/04_parent_samples", clear
	_calc_cf, title("West German Women") anchor(2) part(2) coh(`coh')
	mat WW`coh' = e(ret)
	use "${tempDir}/04_parent_samples", clear
	_calc_cf, title("East German Women") anchor(2) part(1) coh(`coh')
	mat EW`coh' = e(ret)
	use "${tempDir}/04_parent_samples", clear
	_calc_cf, title("West German Men") anchor(1) part(2) coh(`coh')
	mat WM`coh' = e(ret)
	use "${tempDir}/04_parent_samples", clear
	_calc_cf, title("East German Women") anchor(1) part(1) coh(`coh')
	mat EM`coh' = e(ret)
}

mat A = WW1 \ WW2 \ WW3 \ WW4 \ EW1 \ EW2 \ EW3 \ EW4 \ ///
		WM1 \ WM2 \ WM3 \ WM4 \ EM1 \ EM2 \ EM3 \ EM4 

* Create a new dataset with predictions
clear
svmat A, names(col) 

lab def scenario ///
		0 "observed" ///
	    1 "S1: If H had fertility of L" ///
		2 "S2: If L had fertility of H" ///
		3 "S3: if H had behaviour of L" ///
		4 "S4: if L had behaviour of H" ///
		, modify
		
lab val scenario scenario

* lab def coh 1 "30-35" 2 "36-40" 3 "41-45" 4 "46-50", modify
lab def coh 1 "1930-35" 2 "1936-40" 3 "1941-45" 4 "1946-50", modify
lab val coh coh 		

gen OR = exp(lnOR)		

* Estimates: 

li scenario lnOR coh if anchor == 2 & part == 2
li scenario H_perc coh if anchor == 2 & part == 2
li scenario G1_perc coh if anchor == 2 & part == 2


/*-----------------------------------------------------------

Table B7. Projection values for scenario analysis. 
Table B8. Projection values for scenario analysis (part II) – 
		  Inequality of educational opportunity in G2 expressed by the 
		  differences in probability of attaining high education 
		  by parental education.

	=> exported to an excel file
-----------------------------------------------------------*/

preserve 
	egen group = group(anchor part coh)
	reshape wide H_perc G1_perc lnOR OR probdiff, i(group) j(scenario)  
	
	lab def anchor 1 "Men" 2 "Women", modify
	lab def part 1 "East" 2 "West", modify
	lab val anchor anchor
	lab val part part
	
	gsort +part -anchor +coh
	
	keep part anchor coh G1_perc? H_perc? lnOR? probdiff?
	order part anchor coh G1_perc? H_perc? lnOR? probdiff?
	export excel using "${logDir}/Table_B7_B8_projection-values-scenario-analysis.xlsx", replace  firstrow(variables)
restore

/*-----------------------------------------------------------

 Figure 6 (Scenario analyses)
 
-----------------------------------------------------------*/

* Inequality among the offspring (log odds ratio) [original colors commented out]	
local colobs "black"
local colS1  "gs3" 	// "cranberry%80" 
local colS2  "gs10" // "cranberry%40" 
local colS3  "gs3" 	// "green%80"
local colS4  "gs10" // "green%40"

* East - Men 	
twoway (scatter lnOR coh if scenario == 0  & anchor == 1 & part == 1, sort c(l) msymb(O) lpat(solid) col(`colobs')) ///
	   (scatter lnOR coh if scenario == 1  & anchor == 1 & part == 1, sort c(l) msymb(Dh) lpat(shortdash) col(`colS1')) ///
	   (scatter lnOR coh if scenario == 2  & anchor == 1 & part == 1, sort c(l) msymb(Dh) lpat(shortdash) col(`colS2')) ///
	   (scatter lnOR coh if scenario == 3  & anchor == 1 & part == 1, sort c(l) msymb(Th) lpat(dash) col(`colS3')) /// 
	   (scatter lnOR coh if scenario == 4  & anchor == 1 & part == 1, sort c(l) msymb(Th) lpat(dash) col(`colS4')) /// 
	   , legend(lab(1 "Observed") ///
				lab(2 "S1: If H had fertility of L") ///
				lab(3 "S2: If L had fertility of H") ///
				lab(4 "S3: if H's children had L's attainment behavior") ///
				lab(5 "S4: if L's children had H's attainment behavior") ///
				size(small) row(3) order(1 2 3 4 5) ring(0) pos(3)) ylabel(0(.5)2.5, grid) ymtick(0(.55)2.5) ///
				xlabel(,  val) ///
				ytitle("Log-odds ratio") scheme(lean1) xtitle("") ///
				name(EM1, replace) title("Men – East") graphregion(fcolor(none)) plotregion(fcolor(none) lcolor(black)) 	
* East - Women 	
twoway (scatter lnOR coh if scenario == 0  & anchor == 2 & part == 1, sort c(l) msymb(O) lpat(solid) col(`colobs')) ///
	   (scatter lnOR coh if scenario == 1  & anchor == 2 & part == 1, sort c(l) msymb(Dh) lpat(shortdash) col(`colS1')) ///
	   (scatter lnOR coh if scenario == 2  & anchor == 2 & part == 1, sort c(l) msymb(Dh) lpat(shortdash) col(`colS2')) ///
	   (scatter lnOR coh if scenario == 3  & anchor == 2 & part == 1, sort c(l) msymb(Th) lpat(dash) col(`colS3')) /// 
	   (scatter lnOR coh if scenario == 4  & anchor == 2 & part == 1, sort c(l) msymb(Th) lpat(dash) col(`colS4')) /// 
	   , legend(lab(1 "Observed") ///
				lab(2 "S1: If H had fertility of L") ///
				lab(3 "S2: If L had fertility of H") ///
				lab(4 "S3: if H's children had L's attainment behavior") ///
				lab(5 "S4: if L's children had H's attainment behavior") ///
				size(small) row(3) order(1 2 3 4 5) ring(0) pos(9)) ylabel(0(.5)2.5, grid) ymtick(0(.55)2.5) ///
				xlabel(,  val) ///
				ytitle("Log-odds ratio") scheme(lean1) xtitle("") ///
				name(EW1, replace) title("Women – East") graphregion(fcolor(none)) plotregion(fcolor(none) lcolor(black)) 				
* West - Men 	
twoway (scatter lnOR coh if scenario == 0  & anchor == 1 & part == 2, sort c(l) msymb(O) lpat(solid) col(`colobs')) ///
	   (scatter lnOR coh if scenario == 1  & anchor == 1 & part == 2, sort c(l) msymb(Dh) lpat(shortdash) col(`colS1')) ///
	   (scatter lnOR coh if scenario == 2  & anchor == 1 & part == 2, sort c(l) msymb(Dh) lpat(shortdash) col(`colS2')) ///
	   (scatter lnOR coh if scenario == 3  & anchor == 1 & part == 2, sort c(l) msymb(Th) lpat(dash) col(`colS3')) /// 
	   (scatter lnOR coh if scenario == 4  & anchor == 1 & part == 2, sort c(l) msymb(Th) lpat(dash) col(`colS4')) /// 
	   , legend(lab(1 "Observed") ///
				lab(2 "S1: If H had fertility of L") ///
				lab(3 "S2: If L had fertility of H") ///
				lab(4 "S3: if H's children had L's attainment behavior") ///
				lab(5 "S4: if L's children had H's attainment behavior") ///
				size(small) row(3) order(1 2 3 4 5) ring(0) pos(3)) ylabel(0(.5)2.5, grid) ymtick(0(.55)2.5) ///
				xlabel(,  val) ///
				ytitle("Log-odds ratio") scheme(lean1) xtitle("") ///
				name(WM1, replace) title("Men – West")	graphregion(fcolor(none)) plotregion(fcolor(none) lcolor(black)) 		
* West - Women 	
twoway (scatter lnOR coh if scenario == 0  & anchor == 2 & part == 2, sort c(l) msymb(O) lpat(solid) col(`colobs')) ///
	   (scatter lnOR coh if scenario == 1  & anchor == 2 & part == 2, sort c(l) msymb(Dh) lpat(shortdash) col(`colS1')) ///
	   (scatter lnOR coh if scenario == 2  & anchor == 2 & part == 2, sort c(l) msymb(Dh) lpat(shortdash) col(`colS2')) ///
	   (scatter lnOR coh if scenario == 3  & anchor == 2 & part == 2, sort c(l) msymb(Th) lpat(dash) col(`colS3')) /// 
	   (scatter lnOR coh if scenario == 4  & anchor == 2 & part == 2, sort c(l) msymb(Th) lpat(dash) col(`colS4')) /// 
	   , legend(lab(1 "Observed") ///
				lab(2 "S1: If H had fertility of L") ///
				lab(3 "S2: If L had fertility of H") ///
				lab(4 "S3: if H's children had L's attainment behavior") ///
				lab(5 "S4: if L's children had H's attainment behavior") ///
				size(small) row(3) order(1 2 3 4 5) ring(0) pos(3)) ylabel(0(.5)2.5, grid) ymtick(0(.55)2.5) ///
				xlabel(,  val) ///
				ytitle("Log-odds ratio") scheme(lean1) xtitle("") ///
				name(WW1, replace) title("Women – West") graphregion(fcolor(none)) plotregion(fcolor(none) lcolor(black)) 			

grc1leg EM1 WM1 EW1 WW1, rows(1) title("G2 – IEO (log-odds ratio)") legendfrom(EM1) xsize(10) ysize(15) scheme(lean1) graphregion(margin(0 0 0 0)) imargin(1 1 1 1)  name(lnOR, replace)

* % of higher educated 
* East - Men 	
twoway (scatter H_perc coh if scenario == 0  & anchor == 1 & part == 1, sort c(l) msymb(O) lpat(solid) col(`colobs')) ///
	   (scatter H_perc coh if scenario == 1  & anchor == 1 & part == 1, sort c(l) msymb(Dh) lpat(shortdash) col(`colS1')) ///
	   (scatter H_perc coh if scenario == 2  & anchor == 1 & part == 1, sort c(l) msymb(Dh) lpat(shortdash) col(`colS2')) ///
	   (scatter H_perc coh if scenario == 3  & anchor == 1 & part == 1, sort c(l) msymb(Th) lpat(dash) col(`colS3')) /// 
	   (scatter H_perc coh if scenario == 4  & anchor == 1 & part == 1, sort c(l) msymb(Th) lpat(dash) col(`colS4')) /// 
	   , legend(lab(1 "Observed") ///
				lab(2 "S1: If H had fertility of L") ///
				lab(3 "S2: If L had fertility of H") ///
				lab(4 "S3: if H's children had L's attainment behavior") ///
				lab(5 "S4: if L's children had H's attainment behavior") ///
				size(small) row(3) order(1 2 3 4 5) ring(0) pos(11)) ylabel(0(25)100, grid) ymtick(0(12.5)100) ///
				xlabel(,  val) ///
				ytitle("Percent") scheme(lean1) xtitle("") ///
				name(EM2, replace) title("Men – East")	graphregion(fcolor(none)) plotregion(fcolor(none) lcolor(black))  	
* East - Women 	
twoway (scatter H_perc coh if scenario == 0  & anchor == 2 & part == 1, sort c(l) msymb(O) lpat(solid) col(`colobs')) ///
	   (scatter H_perc coh if scenario == 1  & anchor == 2 & part == 1, sort c(l) msymb(Dh) lpat(shortdash) col(`colS1')) ///
	   (scatter H_perc coh if scenario == 2  & anchor == 2 & part == 1, sort c(l) msymb(Dh) lpat(shortdash) col(`colS2')) ///
	   (scatter H_perc coh if scenario == 3  & anchor == 2 & part == 1, sort c(l) msymb(Th) lpat(dash) col(`colS3')) /// 
	   (scatter H_perc coh if scenario == 4  & anchor == 2 & part == 1, sort c(l) msymb(Th) lpat(dash) col(`colS4')) /// 
	   , legend(lab(1 "Observed") ///
				lab(2 "S1: If H had fertility of L") ///
				lab(3 "S2: If L had fertility of H") ///
				lab(4 "S3: if H's children had L's attainment behavior") ///
				lab(5 "S4: if L's children had H's attainment behavior") ///
				size(small) row(3) order(1 2 3 4 5) ring(0) pos(9)) ylabel(0(25)100, grid) ymtick(0(12.5)100) ///
				xlabel(,  val) ///
				ytitle("Percent") scheme(lean1) xtitle("") ///
				name(EW2, replace) title("Women – East")	graphregion(fcolor(none)) plotregion(fcolor(none) lcolor(black))  		
* West - Men 	
twoway (scatter H_perc coh if scenario == 0  & anchor == 1 & part == 2, sort c(l) msymb(O) lpat(solid) col(`colobs')) ///
	   (scatter H_perc coh if scenario == 1  & anchor == 1 & part == 2, sort c(l) msymb(Dh) lpat(shortdash) col(`colS1')) ///
	   (scatter H_perc coh if scenario == 2  & anchor == 1 & part == 2, sort c(l) msymb(Dh) lpat(shortdash) col(`colS2')) ///
	   (scatter H_perc coh if scenario == 3  & anchor == 1 & part == 2, sort c(l) msymb(Th) lpat(dash) col(`colS3')) /// 
	   (scatter H_perc coh if scenario == 4  & anchor == 1 & part == 2, sort c(l) msymb(Th) lpat(dash) col(`colS4')) /// 
	   , legend(lab(1 "Observed") ///
				lab(2 "S1: If H had fertility of L") ///
				lab(3 "S2: If L had fertility of H") ///
				lab(4 "S3: if H's children had L's attainment behavior") ///
				lab(5 "S4: if L's children had H's attainment behavior") ///
				size(small) row(3) order(1 2 3 4 5) ring(0) pos(3)) ylabel(0(25)100, grid) ymtick(0(12.5)100) ///
				xlabel(,  val) ///
				ytitle("Percent") scheme(lean1) xtitle("") ///
				name(WM2, replace) title("Men – West")	graphregion(fcolor(none)) plotregion(fcolor(none) lcolor(black)) 
* West - Women 	
twoway (scatter H_perc coh if scenario == 0  & anchor == 2 & part == 2, sort c(l) msymb(O) lpat(solid) col(`colobs')) ///
	   (scatter H_perc coh if scenario == 1  & anchor == 2 & part == 2, sort c(l) msymb(Dh) lpat(shortdash) col(`colS1')) ///
	   (scatter H_perc coh if scenario == 2  & anchor == 2 & part == 2, sort c(l) msymb(Dh) lpat(shortdash) col(`colS2')) ///
	   (scatter H_perc coh if scenario == 3  & anchor == 2 & part == 2, sort c(l) msymb(Th) lpat(dash) col(`colS3')) /// 
	   (scatter H_perc coh if scenario == 4  & anchor == 2 & part == 2, sort c(l) msymb(Th) lpat(dash) col(`colS4')) /// 
	   , legend(lab(1 "Observed") ///
				lab(2 "S1: If H had fertility of L") ///
				lab(3 "S2: If L had fertility of H") ///
				lab(4 "S3: if H's children had L's attainment behavior") ///
				lab(5 "S4: if L's children had H's attainment behavior") ///
				size(small) row(3) order(1 2 3 4 5) ring(0) pos(3)) ylabel(0(25)100, grid) ymtick(0(12.5)100) ///
				xlabel(,  val) ///
				ytitle("Percent") scheme(lean1) xtitle("") ///
				name(WW2, replace) title("Women – West")	graphregion(fcolor(none)) plotregion(fcolor(none) lcolor(black)) 

grc1leg EM2 WM2 EW2 WW2, rows(1) title("G2 – Educational Distribution (% Higher educated)") legendfrom(EM2) xsize(10) ysize(15) scheme(lean1) graphregion(margin(0 0 0 0) color(none) lwidth(none)) imargin(1 1 1 1)  name(H_perc, replace)

* % G2/G1
* East - Men 	
twoway (scatter G1_perc coh if scenario == 0  & anchor == 1 & part == 1, sort c(l) msymb(O) lpat(solid) col(`colobs')) ///
	   (scatter G1_perc coh if scenario == 1  & anchor == 1 & part == 1, sort c(l) msymb(Dh) lpat(shortdash) col(`colS1')) ///
	   (scatter G1_perc coh if scenario == 2  & anchor == 1 & part == 1, sort c(l) msymb(Dh) lpat(shortdash) col(`colS2')) ///
	   (scatter G1_perc coh if scenario == 3  & anchor == 1 & part == 1, sort c(l) msymb(Th) lpat(dash) col(`colS3')) /// 
	   (scatter G1_perc coh if scenario == 4  & anchor == 1 & part == 1, sort c(l) msymb(Th) lpat(dash) col(`colS4')) /// 
	   , legend(lab(1 "Observed") ///
				lab(2 "S1: If H had fertility of L") ///
				lab(3 "S2: If L had fertility of H") ///
				lab(4 "S3: if H's children had L's attainment behavior") ///
				lab(5 "S4: if L's children had H's attainment behavior") ///
				size(small) row(3) order(1 2 3 4 5) ring(0) pos(11)) ylabel(150(25)225, grid) ymtick(150(12.5)225) ///
				xlabel(,  val) ///
				ytitle("Percent") scheme(lean1) xtitle("") ///
				name(EM3, replace) title("Men – East")	graphregion(fcolor(none)) plotregion(fcolor(none) lcolor(black)) 
* East - Women 	
twoway (scatter G1_perc coh if scenario == 0  & anchor == 2 & part == 1, sort c(l) msymb(O) lpat(solid) col(`colobs')) ///
	   (scatter G1_perc coh if scenario == 1  & anchor == 2 & part == 1, sort c(l) msymb(Dh) lpat(shortdash) col(`colS1')) ///
	   (scatter G1_perc coh if scenario == 2  & anchor == 2 & part == 1, sort c(l) msymb(Dh) lpat(shortdash) col(`colS2')) ///
	   (scatter G1_perc coh if scenario == 3  & anchor == 2 & part == 1, sort c(l) msymb(Th) lpat(dash) col(`colS3')) /// 
	   (scatter G1_perc coh if scenario == 4  & anchor == 2 & part == 1, sort c(l) msymb(Th) lpat(dash) col(`colS4')) /// 
	   , legend(lab(1 "Observed") ///
				lab(2 "S1: If H had fertility of L") ///
				lab(3 "S2: If L had fertility of H") ///
				lab(4 "S3: if H's children had L's attainment behavior") ///
				lab(5 "S4: if L's children had H's attainment behavior") ///
				size(small) row(3) order(1 2 3 4 5) ring(0) pos(9)) ylabel(150(25)225, grid) ymtick(150(12.5)225) ///
				xlabel(,  val) ///
				ytitle("Percent") scheme(lean1) xtitle("") ///
				name(EW3, replace) title("Women – East")	graphregion(fcolor(none)) plotregion(fcolor(none) lcolor(black))  	
* West - Men 	
twoway (scatter G1_perc coh if scenario == 0  & anchor == 1 & part == 2, sort c(l) msymb(O) lpat(solid) col(`colobs')) ///
	   (scatter G1_perc coh if scenario == 1  & anchor == 1 & part == 2, sort c(l) msymb(Dh) lpat(shortdash) col(`colS1')) ///
	   (scatter G1_perc coh if scenario == 2  & anchor == 1 & part == 2, sort c(l) msymb(Dh) lpat(shortdash) col(`colS2')) ///
	   (scatter G1_perc coh if scenario == 3  & anchor == 1 & part == 2, sort c(l) msymb(Th) lpat(dash) col(`colS3')) /// 
	   (scatter G1_perc coh if scenario == 4  & anchor == 1 & part == 2, sort c(l) msymb(Th) lpat(dash) col(`colS4')) /// 
	   , legend(lab(1 "Observed") ///
				lab(2 "S1: If H had fertility of L") ///
				lab(3 "S2: If L had fertility of H") ///
				lab(4 "S3: if H's children had L's attainment behavior") ///
				lab(5 "S4: if L's children had H's attainment behavior") ///
				size(small) row(3) order(1 2 3 4 5) ring(0) pos(3)) ylabel(150(25)225, grid) ymtick(150(12.5)225) ///
				xlabel(,  val) ///
				ytitle("Percent") scheme(lean1) xtitle("") ///
				name(WM3, replace) title("Men – West")	graphregion(fcolor(none)) plotregion(fcolor(none) lcolor(black)) 
* West - Women 	
twoway (scatter G1_perc coh if scenario == 0  & anchor == 2 & part == 2, sort c(l) msymb(O) lpat(solid) col(`colobs')) ///
	   (scatter G1_perc coh if scenario == 1  & anchor == 2 & part == 2, sort c(l) msymb(Dh) lpat(shortdash) col(`colS1')) ///
	   (scatter G1_perc coh if scenario == 2  & anchor == 2 & part == 2, sort c(l) msymb(Dh) lpat(shortdash) col(`colS2')) ///
	   (scatter G1_perc coh if scenario == 3  & anchor == 2 & part == 2, sort c(l) msymb(Th) lpat(dash) col(`colS3')) /// 
	   (scatter G1_perc coh if scenario == 4  & anchor == 2 & part == 2, sort c(l) msymb(Th) lpat(dash) col(`colS4')) /// 
	   , legend(lab(1 "Observed") ///
				lab(2 "S1: If H had fertility of L") ///
				lab(3 "S2: If L had fertility of H") ///
				lab(4 "S3: if H's children had L's attainment behavior") ///
				lab(5 "S4: if L's children had H's attainment behavior") ///
				size(small) row(3) order(1 2 3 4 5) ring(0) pos(3)) ylabel(150(25)225, grid) ymtick(150(12.5)225) ///
				xlabel(,  val) ///
				ytitle("Percent") scheme(lean1) xtitle("") ///
				name(WW3, replace) title("Women – West") graphregion(fcolor(none)) plotregion(fcolor(none) lcolor(black)) 	
			
				
// different display - wide
grc1leg EM2 WM2 EW2 WW2, rows(2) title("G2 – Educational Distribution (% Higher educated)") legendfrom(EM2) xsize(10) ysize(15) scheme(lean1) graphregion(margin(0 0 0 0)) imargin(2 2 2 2)  name(H_perc, replace)
grc1leg EM1 WM1 EW1 WW1, rows(2) title("G2 – IEO (log-odds ratio)") ycommon legendfrom(EM1) xsize(10) ysize(15) scheme(lean1) graphregion(margin(0 0 0 0)) imargin(2 2 2 2)  name(lnOR, replace)				
grc1leg EM3 WM3 EW3 WW3, rows(2) title("Population renewal (% G2/G1)") legendfrom(EM3) xsize(10) ysize(15) scheme(lean1) graphregion(margin(0 0 0 0)) imargin(2 2 2 2)  name(G1_perc, replace)
				
grc1leg G1_perc H_perc lnOR, cols(3) legendfrom(G1_perc) xsize(15) ysize(10) scheme(lean1) graphregion(margin(0 0 0 0)) imargin(5 5 5 5) iscale(*.6) name(all, replace)
graph play grec/adjust-figure-population-simulation-wide.grec
graph play grec/adjust-figure-population-simulation-wide-2.grec
graph export "${logDir}/Figure_6-projection-scenario-analyses.pdf", replace

/*
/* Alternative Figure design to fit the Demography layout */
// https://www.springer.com/journal/13524/submission-guidelines#Instructions%20for%20Authors_Artwork%20and%20Illustrations%20Guidelines 

* 1 inch = 25.4 mm 
* Small journals: 119 mm wide (4.685 inch), 195 mm (7.677 inch) high (max)

grc1leg EM2 WM2 EW2 WW2, rows(2) title("G2 – Educational Distribution (% High-educated)") legendfrom(EM2) xsize(10) ysize(15) ycommon scheme(lean1) graphregion(margin(0 0 0 0) color(none) lwidth(none)) imargin(1 1 1 1)  name(H_perc, replace)
grc1leg EM1 WM1 EW1 WW1, rows(2) title("G2 – IEO (log-odds ratio)")  legendfrom(EM1) xsize(10) ysize(15) scheme(lean1) ycommon graphregion(margin(0 0 0 0) color(none) lwidth(none)) imargin(1 1 1 1)  name(lnOR, replace)				
grc1leg EM3 WM3 EW3 WW3, rows(2) title("Population renewal (% G2/G1)") legendfrom(EM3) xsize(10) ysize(15) scheme(lean1) ycommon graphregion(margin(0 0 0 0) color(none) lwidth(none)) imargin(1 1 1 1)  name(G1_perc, replace)
	
grc1leg G1_perc H_perc lnOR, cols(3) ///
		legendfrom(G1_perc) xsize(15) ysize(10) ///
		scheme(lean1) graphregion(margin(0 0 0 0)) ///
		imargin(1 1 1 1) name(Figure_6, replace) iscale(*.8)  // iscale(*.6) 
graph play grec/adjust-figure-population-simulation-wide.grec

graph display Figure_6, ysize(4.685) xsize(7.677) // fix for the xsize / ysize problem with grc1leg

graph play grec/adjust-figure-DEMOGRAPHY-adjust-titles-Figure-6.grec
graph play grec/adjust-figure-DEMOGRAPHY-remove-second-ytitles-Figure-6.grec
graph play grec/adjust-figure-DEMOGRAPHY-remove-thin-lines-Figure-6.grec
graph play grec/adjust-figure-DEMOGRAPHY-adjust-legend-Figure-6.grec
graph play grec/adjust-figure-DEMOGRAPHY-rotate-xlabels-Figure-6.grec
graph play grec/adjust-figure-DEMOGRAPHY-adjust-labelsize-Figure-6.grec

* Wide graph

graph export "${logDir}/Figure_6-WIDE.pdf", replace
graph export "${logDir}/Figure_6-WIDE.svg", replace
graph export "${logDir}/Figure_6-WIDE.eps", replace

*/

